#!/opt/misc/bin/perl
# #!/bin/sh
                                 $hkinfo::version = "hkinfo v1.009 14 Apr 00";
# The brief editor will update this line     Last update::  4-13-100 11:54 am 
#-----------------------------------------------------------------------------
#
#                     III
#  H    H   K    K     I      N    N   FFFFFF    OOOO
#  H    H   K   K      I      NN   N   F        O    O
#  HHHHHH   KKKK       I      N N  N   FFFFF    O    O
#  H    H   K  K       I      N  N N   F        O    O
#  H    H   K   K      I      N   NN   F        O    O
#  H    H   K    K    III     N    N   F         OOOO
#
#-----------------------------------------------------------------------------
#                                      Last update::  4-13-100 8:44 am 
# 1.003 28 Mar 00 dbb Since v16819 & v16817 are currently installed in G/C,
#                     hks must be sure to upload to upper only after a
#                     partial version has move the rx/tx buffers.
#                     This hks does some smart uploading...
# 1.005  7 Apr 00 dbb Added HV tests, Reset Tests, Verbose switch
# 1.006 10 Apr 00 dbb Fixed a bug in cmd, reorganized hks tool into a
#                     collection of .pm files.
# 1.007 13 Apr 00 dbb Sorted collateral lists in preparation for redesign
#                     that assembles lists as needed, instead of explicitly
#                     defining each list.  Should make it clearer and terse.
# 1.009 14 Apr 00 dbb created hkinfo to store the big hashes and other data
#                     structures
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# The 'use strict' direrctive forces the coder to follow rules that might keep
# him out of trouble by calling attention to undeclared variables and the like.
use strict;
use diagnostics -verbose;

  # This hash connects a command opcode to its text name.
%hkinfo::CmdNames = ( 
              0x8080 => "NOOP",
              0x8585 => "DGBWKX",
              0x8686 => "DGBWKY",
              0x8989 => "DGEWKX",
              0x9595 => "DGLQT",
              0x9797 => "DGTTX",
              0x9898 => "DGTTY",
              0x8A8A => "DGEWKY",
              0x8D8D => "DHVMAX",
              0x9E9E => "DESTIM",
              0xA2A2 => "DGUQT",
              0xABAB => "DDTEST",
              0xACAC => "DDPEEK",
              0xADAD => "DDUPLOD",
              0xAEAE => "DDMDNLD",
              0xB4B4 => "DPCNT",
              0xB6B6 => "DHVLO",
              0xBABA => "DPINT",
              0xBCBC => "DPTOFF",
              0xC0C0 => "DHVPWR",
              0xC4C4 => "AUXPWR",
              0xC6C6 => "DHVNM",
              0xCACA => "DPOVRRD",
              0xCBCB => "DHVDAC",
              0xCECE => "DHRAMPT",
              0xD0D0 => "DHVILIM",
              0xD1D1 => "DHVENA",
              0xD5D5 => "DGBOFFY",
              0xD6D6 => "DGEOFFY",
              0xD7D7 => "DGBSCLY",
              0xD8D8 => "DGESCLY",
              0xE1E1 => "DGBOFFX",
              0xE2E2 => "DGEOFFX",
              0xE3E3 => "DGBSCLX",
              0xE4E4 => "DGESCLX",
              0xE6E6 => "DHVLOW",
              0xE7E7 => "DHVNOM",
              0xEAEA => "DDGOTO",
              0xEBEB => "DPDIS",
              0xEEEE => "DDDAY",
              0xEFEF => "DDNITE",
              0xF0F0 => "DDRSTHD",
              0xF1F1 => "DDWDDIS",
              0xF3F3 => "DDJMPCS",
              0xF4F4 => "DDDIAGC",
              0xF5F5 => "DDRSTSO",
              0xF6F6 => "DDIDLE",
              0xFDFD => "DDPRMOF",
              0xFFFF => "DDHKREQ",
              0x0000 => "Not-a-Command!",
            ); # CmdTest

  # This hash connects hkp addresses with a set of text descriptions for that
  # hkp item.  The first two descriptions are short names in GALEX and COS.
  # The other two are as-yet undefined, so there is some place-folder text
  # there now, but we may write longer descriptions for the hkp item to be used
  # in verbose output.  Later.  dbb 4-3-00
%hkinfo::HkpNames = (
             "0x1440" => ["ph","LFGPHA","PHA","PHA"],
             "0x1480" => ["#DGPH1","ph1","ph1","ph1"],
             "0x14c0" => ["#DGPH2","ph2","ph2","ph2"],
             "0x1500" => ["#DGPH3","ph3","ph3","ph3"],
             "0x1540" => ["phb","LFGPHB","PHB","PHB"],
             "0x1640" => ["err","LFDERR","err","err"],
             "0x1648" => ["errp","LFDERRP","errp","errp"],
             "0x1658" => ["dsbits4","#DSBITS4","bits4","bits4"],
             "0x165a" => ["dsbits5","bits5","bits5","bits5"],
             "0x1664" => ["dib_cbuf0","#DDCBUF","LFDCBUF","CMDIMAGE"],
             "0x166c" => ["RS17_PAR0","rs17","rs17","rs17"],
             "0x1670" => ["RS17_PAR1","par1","par1","par1"],
             "0x1674" => ["RS17_PAR2","par2","par2","par2"],
             "0x1678" => ["RS17_PAR3","par3","par3","par3"],
             "0x167c" => ["RS17_PAR4","par4","par4","par4"],
             "0x1680" => ["cnt_timer","#DCTIMEL","LFCTIME","ctimer"],
             "0x1682" => ["notused","#DCTIMEH","notused","notused"],
             "0x1694" => ["cnt_dec","#DCDECL","LFCDECA","tCDEA"],
             "0x1696" => ["notused","#DCDECH","notused","notused"],
             "0x1698" => ["LFCDECB","tCDEB","LFCDECB","LFCDECB"],
             "0x16a4" => ["cnt_tec","#DCTECL","LFCSDC1","tCASA"],
             "0x16a6" => ["notused","#DCTECH","notused","notused"],
             "0x16a8" => ["LFCSDC2","tCASB","LFCSDC2","LFCSDC2"],
             "0x16ac" => ["cnt_fec","#DCFECL","LFCFECA","tCFEA"],
             "0x16ae" => ["notused","#DCFECH","notused","notused"],
             "0x16b0" => ["LFCFECB","tCFEB","LFCFECB","LFCFECB"],
             "0x16bc" => ["dig_boffx","#DGBOFFX","LFGSHFAX","tXSHIFTA"],
             "0x16bd" => ["dig_bscalex","#DGBSCLX","LFGSTRAX","tXSTRETA"],
             "0x16be" => ["dig_eoffx","#DGEOFFX","LFGSHFBX","tXSHIFTB"],
             "0x16bf" => ["dig_escalex","#DGESCLX","LFGSTRBX","tXSTRETB"],
             "0x16c0" => ["temp_det","#DTDET","LFTDVAA","tDET_TEMP"],
             "0x16c1" => ["LFTACT","tDOOR_TEMP","LFTACT","LFTACT"],
             "0x16c2" => ["LFTHVFM","tFLT_TEMP","LFTHVFM","LFTHVFM"],
             "0x16c3" => ["temp_hvps","#DTHVPS","LFTHVPS","tHV_TEMP"],
             "0x16c4" => ["LFTIP","tIP_TEMP","LFTIP","LFTIP"],
             "0x16c5" => ["LFTDVAB","tLAMP_TEMP","LFTDVAB","LFTDVAB"],
             "0x16c6" => ["temp_ampa","#DTAMPA","LFTAMPA","tAMP_A_TEMP"],
             "0x16c7" => ["temp_ampb","#DTAMPB","LFTAMPB","tAMP_B_TEMP"],
             "0x16c8" => ["temp_tdc","#DTTDC","LFTTDCA","tTDC_A_TEMP"],
             "0x16c9" => ["LFTTDCB","tTDC_B_TEMP","LFTTDCB","LFTTDCB"],
             "0x16ca" => ["temp_lvps","#DTLVPS","LFTLVPS","tPC_TEMP"],
             "0x16cb" => ["temp_dib","#DTDIB","LFTDCE","tDP_TEMP"],
             "0x16cc" => ["hv_fhv","#DSFHV","LFHFAN","tF_STAT"],
             "0x16cd" => ["notused","#DVP5D","LFVP5D","tDP5V"],
             "0x16ce" => ["volt_p5dc","#DVP5DB","tIP_1_IMON"],
             "0x16cf" => ["temp_ctrl","#DTCON","tIP_2_IMON"],
             "0x16d0" => ["volt_p21h","#DVP21H","LFVP21D","tLFVP21D"],
             "0x16d1" => ["tUNUSED11","tUNUSED11","tUNUSED11","tUNUSED11"],
             "0x16d2" => ["hv_currmon","#DHIMON","LFHIMONA","tHI_MON_A"],
             "0x16d3" => ["LFHIMONB","tHI_MON_B","LFHIMONB","LFHIMONB"],
             "0x16d4" => ["hv_voltmon","#DHVMON","LFHVMONA","tHV_MON_A"],
             "0x16d5" => ["LFHVMONB","tHV_MON_B","LFHVMONB","LFHVMONB"],
             "0x16d6" => ["LFHQANA","tQ_STAT_A","LFHQANA","LFHQANA"],
             "0x16d7" => ["LFHQANB","tQ_STAT_B","LFHQANB","LFHQANB"],
             "0x16d8" => ["volt_p15t","#DVP15T","LFVP15TA","tTDC_Ap15MON"],
             "0x16d9" => ["LFVP15TB","tTDC_Bp15MON","LFVP15TB","LFVP15TB"],
             "0x16da" => ["volt_p6t","#DVP6T","LFVP5TA","tTDC_Ap5MON"],
             "0x16db" => ["LFVP5TB","tTDC_Bp5MON","LFVP5TB","LFVP5TB"],
             "0x16dc" => ["volt_m15t","#DVM15T","LFVM15TA","tTDC_Am15MON"],
             "0x16dd" => ["LFVM15TB","tTDC_Bm15MON","LFVM15TB","LFVM15TB"],
             "0x16de" => ["volt_m7t","#DVM7T","LFVM5TA","tTDC_Am5MON"],
             "0x16df" => ["LFVM5TB","tTDC_Bm5MON","LFVM5TB","LFVM5TB"],
             "0x16e0" => ["volt_p15d","#DVP15D","LFVP15D","tDP_p15V"],
             "0x16e1" => ["volt_m15d","#DVM15D","LFVM15D","tDP_m15V"],
             "0x16e2" => ["hv_set","#DHVDAC","LFHVSETA","tHV_A_DAC"],
             "0x16e3" => ["LFHVSETB","tHV_B_DAC","LFHVSETB","LFHVSETB"],
             "0x16e4" => ["LFSBITS2","tSTATUS_BITS2","LFSBITS2","LFSBITS2"],
             "0x16e6" => ["dig_uqt","#DGUQT","LFGUQTAX","tUPR_Q_THR_A"],
             "0x16e7" => ["LFGUQTBX","tUPR_Q_THR_B","LFGUQTBX","LFGUQTBX"],
             "0x16e8" => ["dig_bwkx","#DGBWKX","LFGBWKAX","tBEG_WLK_A"],
             "0x16e9" => ["LFGBWKBX","tBEG_WLK_B","LFGBWKBX","LFGBWKBX"],
             "0x16ea" => ["dig_ewkx","#DGEWKX","LFGEWKAX","tEND_WLK_A"],
             "0x16eb" => ["LFGEWKBX","tEND_WLK_B","LFGEWKBX","LFGEWKBX"],
             "0x16ec" => ["tBSL_Q_THR_A","tBSL_Q_THR_A","tBSL_Q_THR_A","tBSL_Q_THR_A"],
             "0x16ed" => ["tBSL_Q_THR_B","tBSL_Q_THR_B","tBSL_Q_THR_B","tBSL_Q_THR_B"],
             "0x16ee" => ["dig_lqt","#DGLQT","LFGLQTAX","tLWR_Q_THR_A"],
             "0x16ef" => ["LFGLQTBX","tLWR_Q_THR_B","LFGLQTBX","LFGLQTBX"],
             "0x16f0" => ["dig_ttx","#DGTTX","LFGTTAX","tLWR_T_THR_A"],
             "0x16f1" => ["LFGTTBX","tLWR_T_THR_B","LFGTTBX","LFGTTBX"],
             "0x16f2" => ["LFSBITS0","tSTATUS_BITS0","LFSBITS0","LFSBITS0"],
             "0x16f4" => ["LFSBITS1","LFSBITS1","LFSBITS1","LFSBITS1"],
             "0x16f5" => ["tUpperBITS1","STIM_ON_A_BIT","tUpperBITS1","tUpperBITS1"],
             "0x16f6" => ["tCRC_Mask_A","tCRC_Mask_A","tCRC_Mask_A","tCRC_Mask_A"],
             "0x16f8" => ["tCRC_Mask_B","tCRC_Mask_B","tCRC_Mask_B","tCRC_Mask_B"],
             "0x16fa" => ["mem_ram","#DMRAM","LFMRAM","tCRC_RAM"],
             "0x16fc" => ["mem_rom","#DMROM","LFMROM","tCRC_ROM"],
             "0x16fe" => ["dib_swver","#DDSWVER","LFDSWVER","tDP_VERSION"],
             "0x1700" => ["cnt_packet","#DCPKTL","LFCPKT","cnt_packet"],
             "0x1702" => ["notused","#DCPKTH","LFDLSTC","tCMD_R"],
             "0x1704" => ["dib_lstc","#DDLSTC","LFHSTATE","dib_lstc"],
             "0x1706" => ["dig_ref","#DGREF","LFGREFA","tVREFA"],
             "0x1707" => ["LFGREFB","tVREFB","LFGREFB","LFGREFB"],
             "0x1708" => ["LFDDIAG0","tDIAG0","LFDDIAG0","LFDDIAG0"],
             "0x1709" => ["LFDDIAG1","tDIAG1","LFDDIAG1","LFDDIAG1"],
             "0x170a" => ["LFRILIM","DOOR_IMAX","LFRILIM","LFRILIM"],
             "0x170b" => ["hv_currlim","#DHVILIM","LFHVILIM","HV_IMAX"],
             "0x170c" => ["dib_cmdx","#DDCMDX","LFDCMDX","tDP_CMD_C"],
             "0x170e" => ["crp_cnt","#DPCNT","LFPCNTA","tSAA_MAX_A"],
             "0x1710" => ["volt_pmon","#DVPMON","LFVPMON","tPMON"],
             "0x1711" => ["LFDDIAG2","tDIAG2","LFDDIAG2","LFDDIAG2"],
             "0x1712" => ["LFSBITS3","tSTATUS_BITS3","LFSBITS3","LFSBITS3"],
             "0x1713" => ["LFHVIDLE","DUMMYB","LFHVIDLE","LFHVIDLE"],
             "0x1714" => ["LFRACTAN","tACT_STAT","LFRACTAN","LFRACTAN"],
             "0x1715" => ["LFRMTRAN","tMOTOR_STAT","LFRMTRAN","LFRMTRAN"],
             "0x1716" => ["LFRAXI","tAUX_MON","LFRAXI","LFRAXI"],
             "0x1717" => ["LFRAXAN","tAUX_STAT","LFRAXAN","LFRAXAN"],
             "0x1718" => ["dib_cmdr","#DDCMDR","LFDCMDR","tDP_CMD_R"],
             "0x171a" => ["mem_crc","#DMSAV","LFMCRC","tSAVE_CRC"],
             "0x171c" => ["crp_int","#DPINT","LFPINTA","tLFPINTA"],
             "0x171d" => ["tSAA_INT_TIME","tSAA_INT_TIME","tSAA_INT_TIME","tSAA_INT_TIME"],
             "0x171e" => ["LFPCNTB","tSAA_MAX_B","LFPCNTB","LFPCNTB"],
             "0x1720" => ["hv_lo","#DHVLO","LFHVLOA","tSAA_HV_A"],
             "0x1721" => ["LFHVLOB","tSAA_HV_B","LFHVLOB","LFHVLOB"],
             "0x1722" => ["crp_off","#DPTIME","LFHVTGTA","tHV_AUTO_R"],
             "0x1723" => ["LFHVTGTB","LFHVTGTB","LFHVTGTB","LFHVTGTB"],
             "0x1724" => ["hv_nom","#DHVNOM","LFHVNOMA","tHV_A_SET"],
             "0x1725" => ["LFHVNOMB","tHV_B_SET","LFHVNOMB","LFHVNOMB"],
             "0x1726" => ["hv_max","#DHVMAX","LFHVMAXA","tHV_A_MAX"],
             "0x1727" => ["LFHVMAXB","tHV_B_MAX","LFHVMAXB","LFHVMAXB"],
             "0x1728" => ["tLFPINTB","LFPINTB","LFPINTB","LFPINTB"],
             "0x172a" => ["LFSMUXRD","LFSMUXRD","LFSMUXRD","LFSMUXRD"],
             "0x172b" => ["LFRACTEN","RLATCH","LFRACTEN","LFRACTEN"],
             "0x172c" => ["dsbits6","#DSBITS6","LFSC1BTS","dsbits6"],
             "0x172d" => ["LFSC2BTS","LFSC2BTS","LFSC2BTS","LFSC2BTS"],
             "0x172e" => ["dig_stim","#DGSTIM","LFGSTIMA","dig_stim"],
             "0x172f" => ["LFGSTIMB","LFGSTIMB","LFGSTIMB","LFGSTIMB"],
             "0x1730" => ["LFDPERF","LFDPERF","LFDPERF","LFDPERF"],
             "0x1734" => ["dib_peek","#DDPEEK","tPOINTMON","dib_peek"],
             "0x1736" => ["dib_mextr","#DDINT","LFDMEXTR","tLFDMEXTR"],
             "0x1737" => ["dib_mdata","#DDCOD","LFDMDATA","tLFDMDATA"],
             "0x1738" => ["dib_mon0","#DDMON","LFDMONS","tLFDMONS"],
             "0x1740" => ["dib_addr0","#DDMADD","LFDMADD","tLFDMADD"],
             "0x1750" => ["dig_bwky","#DGBWKY","LFGBWKAY","dig_bwky"],
             "0x1751" => ["dig_ewky","#DGEWKY","LFGEWKAY","dig_ewky"],
             "0x175a" => ["#DSBITS5","#DSBITS5","#DSBITS5","#DSBITS5"],
             "0x175e" => ["dig_tty","#DGTTY","LFGTTAY","dig_tty"],
             "0x175f" => ["LFGTTBY","LFGTTBY","LFGTTBY","LFGTTBY"],
             "0x1760" => ["dig_boffy","#DGBOFFY","LFGSHFAY","dig_boffy"],
             "0x1761" => ["dig_bscaley","#DGBSCLY","LFGSTRAY","dig_bscaley"],
             "0x1762" => ["dig_eoffy","#DGEOFFY","LFGSHFBY","dig_eoffy"],
             "0x1763" => ["dig_escaley","#DGESCLY","LFGSTRBY","dig_escaley"],
             "0x1766" => ["LFGLQTAY","LFGLQTAY","LFGLQTAY","LFGLQTAY"],
             "0x1767" => ["LFGLQTBY","LFGLQTBY","LFGLQTBY","LFGLQTBY"],
             "0x1768" => ["LFGUQTAY","LFGUQTAY","LFGUQTAY","LFGUQTAY"],
             "0x1769" => ["LFGUQTBY","LFGUQTBY","LFGUQTBY","LFGUQTBY"],
             "0x1772" => ["tLED_IMAGE","tLED_IMAGE","tLED_IMAGE","tLED_IMAGE"],
             "0x1774" => ["hv_rampt","#DHRAMPT","LFHRAMPT","rampt"],
             "0x1776" => ["diag3","LFDDIAG3","tDIAG3","diag3"],
             "0x1777" => ["diag4","LFDDIAG4","tDIAG4","diag4"],
             "0x1778" => ["mem_u7","#DMU7","LFMU7","u7"],
             "0x177a" => ["mem_u2","#DMU2","LFMU2","u2"],
             "0x177c" => ["mem_lower","#DMLWR","LFMLWR","tLower"],
             "0x177e" => ["mem_upper","#DMUPR","LFMUPR","tUpper"],
             "0x1780" => ["dib_diag0","#DDDIAGS","LFDDIAGS","diags"],
             "0x17c0" => ["p5d","LFVP5D","p5d","p5d"]
            ); # HkpNames

@hkinfo::RemoveFromList = ( 
             "0x1640","0x1680","0x1682",
             "0x1660","0x1662","0x1664","0x1666",
             "0x1668","0x166a","0x166c","0x166e",
             "0x16ac", # FECA
             "0x16e0", # VOLT P15D
             "0x16e2", # hvset DACs
             "0x16e4", # ctrs_flag gets set, not sure why dbb 4-6-00
             "0x16f4", # gpflag gets set occasionally, ignore whole bitset for now... dbb 4-6-00
             "0x1700","0x170c","0x1718", # opcode/packet, cmds recvd, cmds executed ctrs.
             "0x1704", # cmd_r, the opcode just executed
             "0x1708", # diag0
             "0x1712", # Status Bits 3, Tik flag moves on HVON?
          #  "0x1726", # hvmax
             "0x1730", # LFDPERF
             "0x1738", "0x173a", "0x173c", "0x173e",
             "0x1740", "0x1742", "0x1744", "0x1746",
             "0x1748", "0x174a", "0x174c", "0x174e",
             "0x1772", # ???
             "0x1780", # diag0 in diag push-down stack
             "0x1782", # second diag in stack
             "0x183c", # debug
             "0x183e", # debug
             "0x1750"); # the ignore list

%hkinfo::HKPset0tb = (
             "0x16c0" => [ 0x00ff, 1 ], # TEMP: GALEX/DIB only ignore all bits in this talkback
             "0x16c2" => [ 0xFF00, 2 ], # Filter Temp
             "0x16c6" => [ 0x00ff, 1 ], # TEMP AMP A/B:GALEX/DIB only 
             "0x16c8" => [ 0x00ff, 1 ], # TDC TEMP: GALEX/DIB only ignore all bits in this talkback
             "0x16ca" => [ 0x00FF, 2 ], # TEMP LVPS
             "0x16ca" => [ 0xFF00, 2 ], # TEMP DIB
           );
%hkinfo::HKPset1tb = (
             "0x16cc" => [ 0x00FF, 1 ], # fstat hv
             "0x16d2" => [ 0x00FF, 4 ], # hv_current monitor should change when HV powered on
             "0x16d4" => [ 0x00FF, 6 ], # HV Volt Mon
             "0x16d6" => [ 0xff00, 1 ], # QSTAT: GALEX/DIB only ignore all bits in this talkback
             "0x1710" => [ 0x00FF, 6 ], # PMON
             "0x17c0" => [ 0x00FF, 8 ], # LFVP5DA
           );
%hkinfo::HKPset2tb = ( # hkp items that shouldn't be changing but do
             "0x16f2" => [ 0x0020, 0 ], # HVON, HVARM
             "0x16dc" => [ 0x00FF, 4 ], # shouldn't change but does volt_m15t 
             "0x16ee" => [ 0x00FF, 1 ], # dig_lqt  
             "0x16d0" => [ 0x00FF, 1 ], # p21v  
             "0x1714" => [ 0x00ff, 1 ], # LFRACTAN: GALEX/DIB only 
             "0x1714" => [ 0xFF00, 2 ], # MTRAN: GALEX/DIB only
             "0x1716" => [ 0x00ff, 1 ], # RAXAN: GALEX/DIB only ignore all bits in this talkback
             "0x1716" => [ 0xff00, 1 ], # RAXI: GALEX/DIB only ignore all bits in this talkback
           );
%hkinfo::HKPbasic = (%hkinfo::HKPset0tb, %hkinfo::HKPset1tb, %hkinfo::HKPset2tb);
%hkinfo::HKXbasic = (%hkinfo::HKPset0tb, %hkinfo::HKPset1tb, %hkinfo::HKPset2tb);

  # This array contains a list of identifiers recognised by the hkprint tool.
@hkinfo::hkpitems = (
    "cntfec",		"cnt_packet",	"cnt_tec",		"cnt_fec",
	"cnt_packet",	"cnt_tec",  	"cnt_dec",	
    "cnt_timer",	"crp_cnt",		"crp_int",		"crp_off",
    "crp_ovd",		"crp_red",		"dib_1hz",		"dib_addr0",
    "dib_addr1",	"dib_addr2",	"dib_addr3",	"dib_addr4",
    "dib_addr5",	"dib_addr6",	"dib_addr7",	"dib_c2rl0",
    "dib_c2rl1",	"dib_cbuf0",	"dib_cbuf1",	"dib_cbuf2",
    "dib_cbuf3",	"dib_cbuf4",	"dib_cbuf5",	"dib_cbuf6",
    "dib_cbuf7",	"dib_cbuf8",	"dib_cbuf9",	"dib_cmdr",
    "dib_cmdx",		"dib_code",		"dib_detid",	"dib_diag0",
    "dib_diag1",	"dib_diag10",	"dib_diag11",	"dib_diag12",
    "dib_diag13",	"dib_diag14",	"dib_diag15",	"dib_diag16",
    "dib_diag17",	"dib_diag18",	"dib_diag19",	"dib_diag2",
    "dib_diag20",	"dib_diag21",	"dib_diag22",	"dib_diag23",
    "dib_diag24",	"dib_diag25",	"dib_diag26",	"dib_diag27",
    "dib_diag28",	"dib_diag29",	"dib_diag3",	"dib_diag30",
    "dib_diag31",	"dib_diag4",	"dib_diag5",	"dib_diag6",
    "dib_diag7",	"dib_diag8",	"dib_diag9",	"dib_fuv",
    "dib_lstc",		"dib_mdata",	"dib_mextr",	"dib_mon0",
    "dib_mon1",		"dib_mon2",		"dib_mon3",		"dib_mon4",
    "dib_mon5",		"dib_mon6",		"dib_mon7",		"dib_nuv",
    "dib_peek",		"dib_prom",		"dib_prom1",	"dib_prom2",
    "dib_swver",	"dib_tdcx",		"dib_tdcy",		"dib_wddis",
    "dig_boffx",	"dig_boffy",	"dig_bscalex",	"dig_bscaley",
    "dig_bwkx",		"dig_bwky",		"dig_eoffx",	"dig_eoffy",
    "dig_escalex",	"dig_escaley",	"dig_ewkx",		"dig_ewky",
    "dig_lqt",		"dig_ref",		"dig_stim",		"dig_ttx",
    "dig_tty",		"dig_uqt",		"dsbits4",		"dsbits5",
    "dsbits6",		"hv_arm",		"hv_currlim",	"hv_currmon",
    "hv_ena",		"hv_fhv",		"hv_idle",		"hv_lo",
    "hv_low",		"hv_max",		"hv_nom",		"hv_nominal",
    "hv_pwr",		"hv_rampt",		"hv_rmp",		"hv_set",
    "hv_v10",		"hv_voltmon",	"mem_crc",		"mem_lower",
    "mem_ram",		"mem_rom",		"mem_u2",		"mem_u7",
    "mem_upper",	"temp_ampa",	"temp_ampb",	"temp_ctrl",
    "temp_det",		"temp_dib",		"temp_hvps",	"temp_lvps",
    "temp_tdc",		"volt_m15d",	"volt_m15t",	"volt_m7t",
    "volt_p15d",	"volt_p15t",	"volt_p21h",	"volt_p5db",
    "volt_p5dc",	"volt_p6t",		"volt_pmon"
              );

# end of hkinfo.pm
