$TITLE ('GALEX/COS Initialization')
$PAGELENGTH(59)
;$SB
;$DEBUG
;THIS IS INITIALZ.A51,                        LAST EDITED ::  7-6-100 10:54 am 
;*****************************************************************************
;
;   III
;    I      N    N      I      TTTTT      I       AA     L        ZZZZZZ
;    I      NN   N      I        T        I      A  A    L            Z
;    I      N N  N      I        T        I     A    A   L           Z
;    I      N  N N      I        T        I     AAAAAA   L          Z
;    I      N   NN      I        T        I     A    A   L         Z
;   III     N    N      I        T        I     A    A   LLLLLL   ZZZZZZ
;
;*****************************************************************************
; v16262 dbb 01-01-99 Moved CLR fFORMAT to initialz on reset only.
; v16703 dbb 09-21-99 Added (RXD_ISR) command-traffic interrupt, restored
; v16771 dbb 02-03-00 Init code w/d state and reset counter added
; v16775 dbb 02-09-00 Developing a init code that is COS-like for the
;                     COS breadboard, and GALEX-like for the commercial DIB
;                     Detected by reading MUX and testing for FF (COS)
; v16778 dbb 02-10-00 Filled unused space with jumps to trap
; v16786 dbb 02-25-00 Added skip-over "HV-off" and "WD disabled" iff bits are
;                     set.  This should be safe because POR resets those bits.
; v16791 dbb 02-29-00 Project detect looks at PH-B, if FF its GALEX
; v16819 dbb 03-14-00 Project detect looks at interrupt, finally works!
; v16839 dbb 03-29-00 A little clean up, removal of debug and xxx code
; v16845 dbb 04-03-00 Removed BSL init... need to do more POR TDC defaults...
; v16867 dbb 04-28-00 Added disable interrupts EA on reset.
; v16876 dbb 05-02-00 Boot State Initialization
; v16882 dbb 05-05-00 IVT area zapped and rewritten on reset.
;                     Boot Mode: OPERATES flag set, allow HV shutoff on reset.
;                     Inserted do-nothing code, with opcode FF, to preserve
;                     option to patch a PROM's init code.
; v16885 dbb 05-07-00 REORGANIZED! New memory and IVT layout, future
;                     uploads will not be compatable with older versions.
; v17000 dbb 05-22-00 Code Review Version
; v17019 dbb 05-31-00 Removed CHECKBREADBOARD from POR init because it
;                     incorrectly reads MUX (project bit not yet set)
; v17043 dbb 06-30-00 Removed all SIO related code: SIO not used!
;*****************************************************************************
$SET (INITIALZ)
$INCLUDE(common.inc)

         NAME INITIALIZATION

;*****************************************************************************
;*****************************************************************************
INITSEG              SEGMENT CODE
              RSEG       INITSEG

; This is the interrupt vector table that must be located at the bottom
;   of memory.
; Updated 2-8-00 to jmp through vectors loaded in RAM.
; Refer to the MCS(R) 51 Microcontroller Family User's Manual for details
; concerning the behavior of the 8051 at reset.
; Comments added per Action Item 1.022
    LJMP   DPUINIT            ; Power-up reset entry point

    LJMP   vRXD0ISR           ; 03H External 0  -- Triggers in the event
                              ;                    of a received 32-bit word
                              ;                    on the primary command
                              ;                    channel.
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vT0_ISR            ; 0BH Timer 0  -- Triggers in the event of a
                              ;                 timer overflow. Occurs at
                              ;                 regular intervals to drive                              ;                 FSW timing.
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vRXD1ISR           ; 13H External 1  -- Triggers in the event
                              ;                    of a received 32-bit word
                              ;                    on the secondary command
                              ;                    channel.
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vT1_ISR            ; 1BH Timer 1
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vSER_ISR           ; 23H Serial Port
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vT2_ISR            ; 2BH Timer 2
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vPCA_ISR           ; 33H PCA
    NOP
    NOP
    NOP
    NOP
    NOP
    LJMP   vAUX_ISR           ; 3BH Undefined (not available on 'FX)

;*****************************************************************************
    FROGS_CODE 66             ; insert FFs to align the next section
;*****************************************************************************
    DB '    GALEX/COS        ',0Dh,0Ah,0 ; Some text for reference
    DB '  Daniel Blackman    ',0Dh,0Ah,0 ; Some text for reference
    DB '  Embedded Programmer',0Dh,0Ah,0 ; Some text for reference
    DB '  POB 20627          ',0Dh,0Ah,0 ; Some text for reference
    DB '  Oakland, CA 94620  ',0Dh,0Ah,0 ; Some text for reference
    DB '   (510) 910-9047    ',0Dh,0Ah,0 ; Some text for reference

;*****************************************************************************
RESET_PAT:      DB 55h,0AAh,0h,0FFh,9Bh,64h
WD_TEST_MSG:    DB 'Testing watchdog reset circuitry...',0Dh,0
RESET_FAILED:   DB 0Ah,' -- reset failed!',0Ah,0Dh,0
HD_TEST_MSG:    DB 'Testing hard reset circuitry...',0Dh,0
RUNNING_MSG:    DB 'Running...',0Dh,0

    SPARE_CODE   3            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  LOAD_RAM_CODE
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
LOAD_RAM_CODE:
; This has to be coordinated with the development tools, specifically
; hexfix aka hexmv.c, which changes the hex code addresses above 8000h
; to addresses 8000h lower.  Note that we are copying from code
; memory to external memory.
;
; Note: Move starts at offset 800 because MON51 uses 8000-8800h
;       and initialz is never called.
    MOV    DPTR,#RAMDEST      ; dest
    MOV    R0,DPL             ; stash pointer away in registers
    MOV    R1,DPH             ; because the one DPTR has many uses
    MOV    DPTR,#RAMSRC       ; source
    MOV    R2,DPL             ; stash pointer away in registers
    MOV    R3,DPH             ; because the one DPTR has many uses
    MOV    DPTR,#LOAD_RAM_CODE ; get a nearby address
    MOV    A,DPH              ; get the high byte, bit 7 indicates RAM/ROM
    ANL    A,#80h             ; turn off other bits
    JNZ    LOAD_ALREADY_DONE

RAMROM:
    CLR    A                  ; A <-- 0
    MOV    DPL,R2             ; load DPTR with stashed pointer
    MOV    DPH,R3             ;  to source address
    MOVC   A,@A+DPTR          ; ans grab the pointed-to value from codespace
    INC    DPTR               ; then advance the pointer to next codespace
    MOV    R2,DPL             ;   item and save the pointer back in registers
    MOV    R3,DPH             ; save source ptr
    MOV    DPL,R0             ; Then load the destination pointer
    MOV    DPH,R1             ; and save the item taken from codespace
    MOVX   @DPTR,A            ; at the pointed-to address in dataspace
    INC    DPTR               ; then advance the dataspace pointer
    MOV    R0,DPL             ; and stash the dest pointer in registers
    MOV    R1,DPH             ; save dest ptr
    MOV    A,R0               ; use lower-byte of address for loop control
    JNZ    RAMROM             ; loop until write to FFFFh --> 0
    CALL   BLINK_LEDS         ; lab users find it helpful to see activity
    MOV    A,R1               ; look at saved high byte of pointer
    CJNE   A,#HIGH(RAMEND),RAMROM   ; loop until write to BFFFh --> C000h
LOAD_ALREADY_DONE:
    RET                           ; LOAD_RAM_CODE
    FROGS_CODE   9            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  FLASH_LEDS
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
FLASH_LEDS:                   ; helpful in lab to catch attention of users
    TOGLEDS 80h               ; toggle most-significant bit of LEDs
    RET                       ; FLASH_LEDS
    FROGS_CODE  10            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  BLINK_LEDS
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
BLINK_LEDS:                    ; helpful in lab to catch attention of users
    MOV    A,R1               ; we want the LEDS to blink while this
    RL     A                  ; routine executes, so we need a bit that
    RL     A                  ; is toggling at a rate one can see. For this,
    RL     A                  ; the 5th bit of the address is used...
    ANL    A,#80h             ; Toggle the LED's 7th bit, all others off.
    STOREX LEDS
    NOP                       ; word alignment
    RET                       ;       BLINK_LEDS
    FROGS_CODE   4            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  LOADPOR
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
; Prepare for Watchdog reset test by loading internal memory with known
;  values.  If the next time we look at these locations 79h..7F they are
;  different, then we think the cause was a power-up reset.
LOADPOR:
    MOV    R0,#SDBUFFR+2      ; load first (highest) address to test
    MOV    R1,#6              ; load number of addresses to test
    MOV    DPTR,#RESET_PAT    ; load address of pattern table
ZNEXT_ADDR:
    DJNZ   R1,ZFILL_NEXT      ; if all test out, a watchdog reset happened
    JMP    ZDOG_WOOF          ; if all test out, a watchdog reset happened
ZFILL_NEXT:
    MOV    A,R1               ; load test index to ACC
    MOVC   A,@A+DPTR          ; fetch the expected value from table
    MOV    @R0,A              ; store the preset value to internal location
    INC    R0                     ; point to next internal address
    JMP    ZNEXT_ADDR         ; loop tested at top
ZDOG_WOOF:
    NOP                       ; word alignment
    RET                       ; LOADPOR:
    FROGS_CODE  12            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  ; Here is where we decide what kind of startup this is
;
; INPUTS -- SDBUFR contains state indicator
; OUTPUTS -- SDBUFR contains new state indicator, RESETCTR incremented
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;
; per Action Item 1.031:
; We detect the type of reset because the DIB/DCE is required to perform a
; self-test and complete initialization on POR, and a partial initialization
; on any other reset.  The original concept was that the DIB/DCE would be 
; reset-tolerant; added requirements to leave watchdog inactive, for example,
; reduce the value of reset-tolerance.  Nonetheless, that explains the original
; design concept built into FUSE code, from which this code descends.

;                                                                            *
;*****************************************************************************
; Here is where we decide what kind of startup this is:
;   1.  Power-up
;   2.  Watchdog test
;   3.  2nd Watchdog or some other (unexpected)
; The following memory locations are used to hold values that are
; uninitialized before a type (1) reset, but assigned a known value
; otherwise.
;
FINDRESETTYPE:                ; find out what kind of reset brought us here
    MOV    R0,#SDBUFFR+2      ; load first address to test
    MOV    R1,#6              ; load number of addresses to test
    MOV    DPTR,#RESET_PAT    ; load address of pattern table
NEXT_ADDR:
    DJNZ   R1,WOOF_TEST       ; if all test out, a watchdog reset happened
    JMP    DOG_WOOF           ;  then all done!
WOOF_TEST:
    MOV    A,R1               ; load test index to ACC
    MOVC   A,@A+DPTR          ; fetch the expected value from table
    MOV    SDBUFFR+1,A        ;  put it at a direct memory reserved for this
    MOV    A,@R0              ; fetch the possibly preset value
    CJNE   A,SDBUFFR+1,NO_WOOF ; and if they aint equal, must be power-up
    INC    R0                 ; point to next internal address
    JMP    NEXT_ADDR          ; check against every item in table
NO_WOOF:                      ; Pattern didn't match, indicates POR
    MOV    SDBUFFR+0,#1       ; state is powerup
    JMP    SHOW_VAL           ; display at LEDS and exit
DOG_WOOF:		              ; Pattern did match, indicates WDR
    MOV    A,SDBUFFR+0        ; prepare to compare the reset state
    CJNE   A,#4,NOT_HARD      ; if they equal, it was a hard reset
    JMP    HARD_TEST          ; test was sucessful
NOT_HARD:
    CJNE   A,#3,FIRST         ; if they equal, it was a first watchdog reset
SECOND:
    INC    RESETCTR           ; keep count of second watchdog resets
    MOV    A,RESETCTR         ; and check for counter rollover
    JZ     NO_WOOF            ; force POR after 255 w/d resets
    REPORT_DIAG DIAG001C      ; Second watchdog reset (unexpected)
    MOV    SDBUFFR+0,#3       ; force a hard reset test
    JMP    SHOW_VAL             ;  exit
    FROGS_CODE   6            ; insert nops to align the next section

HARD_TEST:
    MOV    SDBUFFR+0,#7       ; second watchdog reset (unexpected)
    JMP    SHOW_VAL             ; display at LEDS and exit
FIRST:
    CJNE   A,#1,SECOND        ; if they equal, it was a first watchdog reset
    REPORT_DIAG DIAG001B      ; First watchdog reset (expected test result)
    MOV    SDBUFFR+0,#3       ; first watchdog reset
SHOW_VAL:                    ;  legacy label name, no output done here
    NOP                       ; word alignment
    RET                       ; FINDRESETTYPE

    FROGS_CODE  12            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  ZAPINTERNALMEMORY
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
; This routine puts internal memory in a known state, zapping register space
;  and setting stack contents to zero so CHECK_STACK will recognise overflow.
ZAPINTERNALMEMORY:            ; init stack for CHECK_STACK

; The check stack routine will report only stack excursions up to address 80h
;  but we want to zap the whole stack, including parts accessable indirectly.
; Clear internal memory, except R0, R1, and POR state, below stack area
    MOV    R0,#3              ; start memory location
    MOV    R1,#STACK-3        ; number of bytes to zap
ZAPPEM:
    CJNE   R0,#SDBUFFR+0,ZAPIT ; if R0 points to POR state variable
    AJMP   NOZAPIT            ; then we skip it and don't zap it
ZAPIT:
    MOV    @R0,#0             ; zap that byte
NOZAPIT:
    INC    R0                 ; step through all internal memory
    DJNZ   R1,ZAPPEM
    NOP

; Now zap stack contents so StackCheck can detect stack excursions
    CLR    A                  ; zero for CHECK_STACK
    MOV    R0,SP              ; save SP
ZAPUSH:
    PUSH   ACC                ; zero for stackCheck
    MOV    R1,SP              ; save SP
    CJNE   R1,#0FFh,ZAPUSH    ; loop until stack pointer is FF
ZAPOP:
    MOV    SP,R0              ; restore SP
    RET                       ; ZAPINTERNALMEMORY init stack for CHECK_STACK
;
    FROGS_CODE 3              ; code alignment...
$EJECT
;*****************************************************************************
;
; Subroutine  PRESETFLAGS
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
PRESETFLAGS:                  ; ensure flags are in a known state
    CLR    CTRS_FLAG
    CLR    MUX_FLAG
    CLR    ESS_FLAG           ; GALEX hkp packet size control, set to spec
    CLR    PHS_FLAG
    CLR    SAA_FLAG           ; Let's check SAA, dbb 11-8-96 (BUGGY! 1-7-97)
; removed dbb 6-14-00    CLR    PH_FLAG
    RET                       ; PRESETFLAGS ensure flags are in a known state

    FROGS_CODE   9            ; code alignment...
$EJECT
;*****************************************************************************
;
; Subroutine  PRESETVARIABLES
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
; Variable initialization done on power up.
PRESETVARIABLES:              ; ensure variables are in a known state

    MOV    A,#128             ; default HV_I limit per mag 9-5-97
    STOREX HV_IMAX            ; init active!

    MOV    A,#1Ah             ; make first diagnostic go in slot 0 (mod 32)
    STOREX DIAG_PTR           ; init DIAG_PTR
;
    MOV    R0,#2Ah            ; per abiad 5-19-97
    SETB   OPERATES           ; prevent BOOT-mode error, cleared in main
    CALL   DOOR_I_MAX         ; Door current limit setting
;
    MOV    HVRAMP,#0F7h       ; ramp at a slow rate, not FF
;
    MOV    A,#0               ; init per mag 9/4/97
    STOREX SA_REDUCED         ; init 1  Value of HV at Reduced level, Seg A
    STOREX SB_REDUCED         ; init 1  Value of HV at Reduced level, Seg B
    STOREX tSAA_HV_A          ; SAA_HV_A
    STOREX tSAA_HV_B          ; SAA_HV_B
;
    ASSIGNX SAA_A_TICKS,0     ; Number of seconds(?) hold counter
    ASSIGNX SAA_B_TICKS,0     ; Number of seconds(?) hold counter
;
    MOV    A,#10
    STOREX SA_INT_TIME        ; SAA Integration Time for Count Limit, Seg A
    STOREX SB_INT_TIME        ; SAA Integration Time for Count Limit, Seg B
    STOREX tSAA_INT_TIME      ; SAA_INT_TIME

DEFAULT_TIMEOFF EQU 0         ; Number of seconds(?) to hold HV Auto Reduce
    ASSIGNX SAA_TIMEOFF,DEFAULT_TIMEOFF ; HV Auto Reduce
    ASSIGNX tHV_AUTO_R,DEFAULT_TIMEOFF  ; default HV Auto Reduce
;
DEFAULT_CNT_LMT EQU 4096                ; per mag 9/8/97
    ASSIGNX SA_CNT_LMT,DEFAULT_CNT_LMT  ; default count limits A
    ASSIGNX tSAA_MAX_A,DEFAULT_CNT_LMT  ; default count limits A
    ASSIGNX SB_CNT_LMT,DEFAULT_CNT_LMT  ; default count limits B
    ASSIGNX tSAA_MAX_B,DEFAULT_CNT_LMT  ; default count limits B

    CALL   SAA_A_INIT         ; preset Trigger Table
    CALL   SAA_B_INIT         ; preset Trigger Table

    ASSIGNX TS28,1            ; init PC Packet Counter
    RET                       ; PRESETVARIABLES  variables in a known state
    FROGS_CODE   17           ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  ZAPRAMSPACE
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
ZAPRAMSPACE:                  ; zero to RAM that gets zeroed
    FILL_XDATA  0h,RS00,TS31   ; The whole TS space
    FILL_XDATA  0h,8040h,8800h ; All external variables, sorry -- constant!
    FILL_XDATA 32h,8000h,8040h ; This is the IVT area in RAM init to RETI
    RET                       ; ZAPRAMSPACE zero to RAM that gets zeroed

    FROGS_CODE  11            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  PORMEMORY
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
; These Are the things we do on power up reset only ************************
PORMEMORY:                    ; set memory to reset state
    CALL   ZAPINTERNALMEMORY  ; init stack for CHECK_STACK
    CALL   PRESETFLAGS        ; ensure flags are in a known state
    CALL   LOADPOR            ; loading internal memory with known pattern
    CALL   ZAPRAMSPACE        ; zero to RAM that gets zeroed
    CALL   PRESETVARIABLES    ; ensure variables are in a known state
    RET                       ; PORMEMORY set memory to reset state
$EJECT
;*****************************************************************************
;
; Subroutine  WDRESETTEST
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;***************************************************************************
WDRESETTEST:
    CALL   PORMEMORY          ; set memory to reset state
    SPARE_CODE 3
$IF XSPEC
; per Action Item 1.042, this code is xspec.  However, it may turn out during
; testing that ensuring the CONTEXT registers are initialized was a good idea.
; for now we acquiesce to the review board, which argues that the risks of
; initializing data here outweighs any benefits.  Okay...
    CALL   INIT_TEST_BKGRND   ; lead CRC checking data structures
$ELSE
    SPARE_CODE 3              ; account for xspec code
$ENDIF
    CALL   INITMEMORYMONITORS ; v16748 upload, for prom move this to init
    CALL   IVTINDIR           ; copy indirect ivt to 32k RAM
$IF XSPEC
    CALL   SETPROJECT         ; detect presence of B detector
    JNB    PROJECT,NOTAGAIN   ; could be COS channel 2 traffic, test again
    CALL   SETPROJECT         ; detect presence of B detector
    JNB    PROJECT,NOTAGAIN   ; could be COS channel 2 traffic, test again
    CALL   SETPROJECT         ; detect presence of B detector
    JNB    PROJECT,NOTAGAIN   ; could be COS channel 2 traffic, test again
NOTAGAIN:
$ELSE
    SPARE_CODE 18             ; account for XSPEC code left out
$ENDIF
    FROGS_CODE 14             ; leave room to patch PROM at this strategic

; This is a timeout routine that loops until reset by the watchdog, or
;  drops out and reports and error if the watchdog doesn't work.
; The triple loop below depends in part on the TF2 timer flag which
; was previously setup to turn on every few hundred microseconds.
; The LED is used to determine if the TF2 timer is working right.
    MOV    R1,#0              ; this value was determined empirically
WRT1:
    MOV    R2,#32h            ; best guess, 31 times out (depends on TF2)
WRT2:
    MOV    R3,#0              ; best guess, this is a time out in case TF2
WRT3:                         ;  might never get set by timer.
    JBC    TF2,WRT4           ; TF2 set regularly.
    CALL   RXD0READ           ; Clear BUSY
    CALL   RXD1READ           ; Clear BUSY
    DJNZ   R3,WRT3            ; we expect to reset before this loop completes
WRT4:
    DJNZ   R2,WRT2            ; we expect to reset before this loop completes
    CALL   FLASH_LEDS
    DJNZ   R1,WRT1            ; we expect to reset before this loop completes

    REPORT_DIAG DIAG001D      ; Watchdog reset failed (unexpected)
;
    MOV    A,#03h             ; indicate test failed!
    MOV    SDBUFFR+0,A        ; do hard test anyway
    SPARE_CODE 4              ; a place to set breakpoint during debug
    RET                       ; WDRESETTEST

    FROGS_CODE  19            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  HDRESETTEST
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
HDRESETTEST:                  ; wiggle reset or return 1E
    MOV    SDBUFFR+0,#4       ; indicate a hard reset test in progress
    CPL    HARDRESET          ; toggle reset line for HARDRESET
    CALL   FEED_DOG           ; wait for hard reset only!
    REPORT_DIAG DIAG001E      ; Hardware self-reset failed (unexpected)
    RET                       ; HDRESETTEST

    FROGS_CODE  13            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  CLRSOMEBITS
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
CLRSOMEBITS:                  ; bit initializations performed on every reset:
    NOP
; Action Item 1.039
; Clear the CRP state flags so the CRP machine does not behave as if we are
; in a CRP shutdown mode.  The HSTATE variable is cleared elsewhere, but is
; logically connected to the clearing of these bits.
    CLR    SA_STATE           ; CRP active, not reduced
    CLR    SB_STATE           ; CRP active, not reduced
    RET                       ; CLRSOMEBITS performed on every reset:
    FROGS_CODE   10           ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  INITMEMORYMONITORS
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
INITMEMORYMONITORS:
    ASSIGNX tLFDMADD+0,  18h  ; default initial memory monitor address
    ASSIGNX tLFDMADD+2,  19h  ; default initial memory monitor address
    ASSIGNX tLFDMADD+4,  1Ah  ; default initial memory monitor address
    ASSIGNX tLFDMADD+6,  1Bh  ; default initial memory monitor address
    ASSIGNX tLFDMADD+8,  1Ch  ; default initial memory monitor address
    ASSIGNX tLFDMADD+10, 1Dh  ; default initial memory monitor address
    ASSIGNX tLFDMADD+12, 1Eh  ; default initial memory monitor address
    ASSIGNX tLFDMADD+14, 1Fh  ; default initial memory monitor address
    ASSIGNX tLFDMEXTR,0FFh    ; default initial external/internal select bits
    ASSIGNX tLFDMDATA,0       ; default initial data/code select bits
    RET                       ; INITMEMORYMONITORS

    FROGS_CODE  11            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  WDCONDITIONAL
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
WDCONDITIONAL:                    ; disable the watchdog only after POR
$IF XSPEC
; The purpose of this code is to allow the watchdog function to remain active
; in the event of a watchdog reset, but preventing a timeout-loop by forcing
; a full reset (as-if POR) when the reset counter rolls over (256 resets).
; There is also a means to control the setting of watchdog state after reset
; by turning on the SKIPDOG bit.  The code to turn on this bit is not
; included in the FSW, but could be uploaded with a later FSW version.
;
; Without this code (and per spec), the watchdog is disabled after any reset.
    MOV    A,RESETCTR         ; does reset counter indicate POR?
    CJNE   A,#1,NICE_DOGGY    ; watchdog disabled only after POR
    JB     SKIPDOG,NICE_DOGGY ; means of avoiding disable of dog on reset
    CALL   WD_DISABLE         ; Disable Watchdog
NICE_DOGGY:                   ;
$ELSE
; The per-spec code does not have this feature described above.  The code is
; only slightly more likely to hang, but is less likely to experience a
; timeout-loop that would similarly degrade performance.
    SPARE_CODE 8              ; account for designed code removed per request
; The watchdog is disabled after any reset.
    CALL   WD_DISABLE         ; Disable Watchdog
$ENDIF
    RET                       ; WDCONDITIONAL

    FROGS_CODE   4            ; insert nops to align the next section
$EJECT
;*****************************************************************************
;
; Subroutine  INITIALIZATION
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;                                                                            *
;*****************************************************************************
; Reset Initialization is meant to be entered several times during both POR
; and WD resets.  The first part of the initialization does whatever is
; required to ensure a stable software environment and forces the hardware
; to a safe state as required.  We then determine the source of the reset and
; perform further memory initializations, watchdog reset and hardware test.
;*****************************************************************************
INITIALIZATION:               ; this does all reset handling

; Since BACKGROUND is called during initialization, we will initialize
    SETB   GF0                ; suppress BACKGROUND activity until INIT_BKGRND

; We copy the contents of PROM to the 32k RAM (lower code area).
; This section executes only when a special build is used to create a boot-
; -to-operate PROM version.  While the source code may be identical to that
; used to create the COS boot-mode PROM version, the special behavior is
; created by the linker/locator parameters.  We add code here to
; detect where in PROM or RAM the procedure INIT_T0 (and all others) may be
; found, and skip to the copy when INIT_T0 has been located in PROM.
    MOV    DPTR,#INIT_T0      ; look at some address outside initialz
    MOV    A,DPH              ; look at most significant bit of address
    ANL    A,#80h             ; set the zero flag is the code is located
    JZ     NOCOPY
    CALL   LOAD_RAM_CODE      ; Move executable code to RAM
NOCOPY:
    CALL   INIT_T0            ; must precede MON51 and all SIO

$IF XSPEC
; The purpose of this code is to allow the possibility that HV could be
; preserved in the event of a watchdog reset.  Normally, the HV is powered off
; on any reset.  The code to turn on this bit is not included in the FSW, but
; could be uploaded with a later FSW version.
;
; Without this code (and per spec), the HV is turned off after any reset.
    JB     SKIPSAFE,NOTSAFE   ; means of avoiding HV power off on reset
    SETB   OPERATES           ; prevent BOOT-mode error, cleared in main
    CALL   SAFE_CONTROLS      ; Hardware foreced to a known, safe state
NOTSAFE:
$ELSE
; Here we always turned off HV, stop the door, etc, in the event of any reset.
    SPARE_CODE 3              ; account for designed code removed per rankin
    SETB   OPERATES           ; prevent BOOT-mode error, cleared in main
    CALL   SAFE_CONTROLS      ; Hardware foreced to a known, safe state
$ENDIF

$IF XXX
; Display start-up message to SIO
    CALL   STARTUPSTRING      ; Display start-up message to SIO
$ENDIF

    CALL   FINDRESETTYPE      ; find out what kind of reset brought us here
$EJECT
;***************************************************************************
; Watchdog reset test
;***************************************************************************
    NOP                       ; for code alignment
    CALL   INIT_WD            ; setup WatchDog Timer
    MOV    A,SDBUFFR+0        ; state into ACC for comparison
    CJNE   A,#1,NO_WD_RST_TST ; do this test only on power-up
; Wait for 0C8h PCM counts -- we have got lots of time!  
; Not expected to return, we simulate a 'hung processor' by not stroking
; the watchdog for 10 seconds.
    CALL   WDRESETTEST        ; wait for reset or return diag 1D
                              ; the w/d test could fail, so we continue...
    SPARE_CODE 5
NO_WD_RST_TST:                    ; we come here if we don't need to do w/d test
;***************************************************************************
; Hard Reset Test
;***************************************************************************
    CJNE   A,#3,SKIP_HRT      ; do this test on any reset
    CALL   HDRESETTEST        ; wiggle reset or return 1E
    FROGS_CODE   2            ; insert nops to align the next section
;
SKIP_HRT:
    CLR    A                  ; zero
    STOREX LFHSTATE           ; HV State always init to 0 on any reset
    CALL   CLRSOMEBITS        ; bit initializations performed on every reset:
TEST_RSLT:

    CALL   WDCONDITIONAL      ; disable the watchdog per rankin
    RET                       ; INITIALIZATION does all reset handling

    FROGS_CODE  19            ; insert nops to align the next section

;*****************************************************************************
;
; Main Process: DPUINIT
;                                                                            *
; The Reset vector points here, where we perform whatever initialization
; is required, then pass control to the mainroutine.
;
; INPUTS -- none
; OUTPUTS -- none
;
; v17044 dbb 07-01-00 Added a banner to every called subroutine       
;                       in response to Action Item 1.005                     *
;*****************************************************************************
DPUINIT:
; dbb 4-27-00 added this interrupt disable as a possible cure for the
; mysterious reset bug.  Interrupts are reenabled after local init.
    CLR    EA                 ; be sure interrupts are turned off
    FROGS_CODE  34            ; leave room to patch PROM
; Leave some room to patch the PROM
    MOV    SP,#STACK          ; Setup stack to allow use of call instruction
    FROGS_CODE  29            ; leave room to patch PROM
    CALL   INITIALIZATION     ; this does all reset handling
    FROGS_CODE  22            ; leave room to patch PROM
    JMP    REENTRY            ; start DPU activity...

$IF DEGAP
    FROGS_CODE  509           ; nops fill extra space
    TRAP_CODE     1           ; INITSEG              SEGMENT CODE
$ENDIF

    END                       ; Initialz.A51
