;*******************************  COMMON.INC  ********************************
$GEN
$SAVE
;THIS IS COMMON.INC,                          LAST EDITED ::  7-9-100 11:40 pm 
$NOLIST
;*****************************************************************************
;
;            CCCCC
;           C     C    OOOO    M    M   M    M    OOOO    N    N
;           C         O    O   MM  MM   MM  MM   O    O   NN   N
;           C         O    O   M MM M   M MM M   O    O   N N  N
;           C         O    O   M    M   M    M   O    O   N  N N
;           C     C   O    O   M    M   M    M   O    O   N   NN
;            CCCCC     OOOO    M    M   M    M    OOOO    N    N
;
;*****************************************************************************
; This file should be included in any source file linked to DIB/DCE FSW.
; These commonly used equates help define the hardware layout and hkp layout.
; There are also some macros used by more than one source file.
;
; Per Action Item 1.008, this list documents the "key names/concepts" used
; throughout the source code:
;   FUSE - the heritage system from which this source code is derived
;   GALEX - a sibling system that shares much of the code design and is
;        implemented using the identical source code.
;   1553 - the FUSE communications system that used a similar memory-mapped
;        i/o scheme.  COS/GALEX use a software-driven 422 communications
;        protocol that simulates the behavior of the FUSE 1553.
;   IDS - the FUSE equivalent of the GALEX/DPU or COS/CS.  The IDS drove the
;        timing of the FUSE system at regular one-second intervals.
;   DIB - the GALEX name for what COS calls a DCE and FUSE calls a DPU.
;   DCE - the COS name for waht GALEX calls a DIB and FUSE calls a DPU.
;*****************************************************************************

; dbb  1-16-97  v133a  Added IDS commands SAA_HERE, SAA_OVER, and SAA_MARK
;                      which are used for temporarily shutting down the HV
;                      to protect the detector from regions of external
;                      radiation.
;

; dbb  1-21-97  v134   Added check of AUX_I_MON -- if it is ever MAX_I_MON
;                      we go to safe mode.  MAX_I_MON initialized to 255.
;                      MAX_I_MON set to 0 to disable checking.  Introduced
;                      command SET_MAX_I_MON.  Watchdog status bit copied
;                      to telemetry in STATUS_BITS_2, found in TS28 25
;                      Also introduced SAA,LiF,and SiC mask initialization.
; dbb  1-21-97  v134a  Disabled HIMON checking, enabled by TEST8
; dbb  1-21-97  v134b  HIMON checking enabled by TEST1D & TEST1E;
;                      Swapped LiF & SiC initialized masks
; dbb  1-22-97  v135   Removed ramping HV.  Removed DIAG001F, unnecessary.
;                      HIMON checking initialized to 255.
; dbb  1-22-97  v136   Arrrgh! Initialize TS space to 0 on power-up.
; dbb  2-03-97  v137   Initialized threshold values to mostly non-zero values
;                      specified by mag.
; dbb  2-04-97  v138   Added a state machine to detect latched-to-unlatched
;                      door transitions, and to power-off the actuators two
;                      seconds after the event.  Also, another attempted fix
;                      of the SAA algorithm by initializing tables to large
;                      values on init and after shutdown recovery.
; dbb  2-05-97  v139   Added a state machine to detect unlatched-to-latched
;                      door transitions, and to power-off the motor two
;                      seconds after the event.  Added ACT_RESET command to
;                      initiate door open/close sequence...
;                      Changed the way masks initialized to make boot faster.
; dbb  2-05-97  v140   Fixed a bug in the state-machine design used for
;                      detecting LATCH transitions.  Used RLC instruction
;                      to multiply by 2, but C was set!  Using RL instead.
;                      Also detecting the LATCH bit should be done by looking
;                      at the subaddress space reserved for that purpose --
;                      -- not addressing the h/w!
;                      Initializ to zero internal RAM only on powerup
; dbb  2-06-97  v141   Fixed a bug in the SAA shutdown routine; added some
;                      diagnostics...
; dbb  2-10-97  v142   Fixed a bug in the LATCH state machines
;                      Restored DOOR_OVERRIDE simple function
; dbb  2-14-97  v143   Still fixing bugs in the SAA shutdown routine
; dbb  2-18-97  v144   Still fixing bugs in the SAA shutdown routine,
;                      esp, startup part.  Added an integer version number.
; dbb  2-19-97  v145   Fixed CHECK/POINTMON, writes correctly.
; dbb  2-20-97  v146   Attempts to fix mask upload CRC problem;
;                      used this version for software review
; dbb  2-21-97  v147   Added some ideas after software review: some initial
;                      values to CDC, flag to skip LATCH machine at TEST 15
;                      ACT power timeout tied to MOTORTMR, and set to the
;                      same timeout (MTR_TOUT) when the actuators are powered.
;                      Burned as PROM set.
; dbb  2-21-97  v147x  Working to fix SAA rollover error.
; dbb  2-25-97  v148x  DETECTOR bit no longer used to select mask init.
; dbb  2-27-97  v148i  Added background checking of CRC values over
;                      regions of memory, reports changes as they happen...
; dbb  2-27-97  v148k  Fixed a bug in SAA_A_INIT, which was located in the
;                      code area U7 & U2, which has been powered off.  Moved
;                      to Code RAM area.
;                      Added a couple of state bits to require two consecutive
;                      HV overvoltages before shutting down like SAA.
;                      Some Special Test Command changes, including one to
;                      reset the masks to power-up configuration.
; dbb  3-4-97   v148n  No change in source; problem with upload utilities
;                      may be fixed by adjusting map so that segments are
;                      separated by at least 16 bytes.
; dbb  3-5-97   v148o  Fixed CRC locations for TS27
; dbb  3-10-97  v149b  Moved some telemetry around, overwrite lesser values
; dbb  3-12-97  v149z  Uploads sometimes write to Mask A... debug versions
; dbb  3-15-97  v150   More fixes -- must set CONTEXT before calling background
; dbb  3-16-97  v151   Added debug sio to examine mask BOX performance
; dbb  3-31-97  v152   Well, DPU151 had a few errors relating to the new
;                      telemetry layout.  Still debugging boxes.
; dbb  4-03-97  v153   Similar fixes, new telemetry layout.
; dbb  4-05-97  v154a  Replaced BYTE_MOVE with cBYTE_MOVE where masks
;                      are not involved... trying to fix inability to
;                      upload!  Fixed more typos.   Grr!
; dbb  4-05-97  v154   Delivered with flight unit #2
; dbb  4-30-97  v155   Fixed box commands.  Background Mask CRC checking
;                      is now done on command only.
; dbb  5-1-97   v155a  Test commands to increment timer speed.
;                      Use TEST B to select among Timer sources
;                      Use TEST C to select between 13/16 bit Timer 0
; dbb  5-9-97   v156   Rewrote BOX commands, added AUX_I overcurrent shutdown
;                      Init DOOR_I_MAX to 3Bh
;                      Init Timer 0 mode to 13-bit source, 'stead of 16-bit,
;                      so timer ticks happen every 6.144 ms, or 162.76 ticks/s
;                      Modified Default_Mask to 30-4-30, 'stead of 28-8-28
;                      format bit in telemetry?
;                      fix move_byte for crcs?
; dbb  5-19-97  v156a  Trivial: init DOOR_I_MAX to 2Ah
; dbb  5-22-97  v157   Fixes arising from review of test plan:
;                      1) MotorTmr set when ARMed
;                      2) PROM power not turned off.
;                      Removed MOTORTMR test at REENTRY
;                      Added copy of SAA_HV_A&B to TS28/17
;                      Added copy of SAA_TOFF to TS28/18
; dbb  5-30-97  v158   Status_Bits1 & 2 redefined! and finally corrected.
;                        Noted but not fixed:
;                      3) SAA_OVER before SAA_HERE uses un-init HV settings;
;                      4) Fix Stuck-semaphore detection
; dbb  7-09-97  v159   BOX command height incremented by one.
;                      SAA_OVER command resets SAA mode
;                      MOTOR_ENA_BIT <== MOTOR_ON
;                      SAA init values to telemetry
; dbb  7-21-97  v160   SAA and HV shutdown schemes have been divorced.
;                      HV_I checking turns off HV if 255
;                      two sequential HV_I overcurrents trigger HV <-- 0
;                      checking stops until next 1553 signal
;                      overcurrent at the next 1553 signal turns off HV
; dbb  9-3-97   v161   Replaced TS+offset references with symbolic constants,
;                      repaired diagnostic code organization.
;                      fixed WATCHDOG_STATE bit.
;                      SAA_TIMEOFF no longer disables SAA checking, but if 0
;                      will not autonomously end SAA shutdown.
;                      Fixed HV_IMAX overcurrent shutdown routine.
;                      Default current limit to 128, HV_IMAX
;                      Default SAA shutdown time 0 (indefinite shutdown)
;                      No more diag code 2C when swapping code
; dbb  9-16-97  v162   Released as Flight Firmware
; dbb  7-21-98  v163   Uploadable version fixes known bugs
;                      zapped diag 13
;                      HV max & dac to tlm
; dbb  9-23-98  16226  Added temp stability flags for demo.
; dbb  11-16-98 16234  Added NOP_FLAG check to background
; dbb  11-18-98 16236  Removed Monitor
; dbb  11-22-98 16238  Fixed Here/Over to behave just like SAA/Rec
; dbb  11-25-98 16242  HV Ramp stuff added
; dbb  12-22-98 16255  Added HVI sampling to Upper Data Area C000
; dbb  12-23-98 16256  HVI algorithm powers off on first overcurrent sample
; dbb  12-24-98 16257  Moved tHV_x_MAX to TS28 23h, 24h.
;                      HVI algorithm powers off on first overcurrent sample
;                      added INIT_HV_RAMP
; dbb  12-28-98 16260  HVI trigger stops any ramping, instead of power-off
;                      HVI sampling only when power-on
; v16264 dbb 01-05-99  Added sampling memory constants, SAMPFSTA, etc.
; v16300 dbb 01-08-99  Released to FUSE project for upload to v16200 in PROM.
; v16400 dbb 01-08-99  Released to FUSE project for upload to v16200 in PROM.
; v16413 dbb 02-09-99  Dropped FSTAT in favor of timestamping records with CL
; v16414 dbb 02-09-99  Removed TELEMETRY_HVI
; v16416 dbb 02-09-99  Replaced TELEMETRY_HVI bits with RAMPxCMD
; v16420 dbb 02-10-99  Clean up for delivery as v165
; v16500 dbb 02-12-99  Upload version released.
; v16701 dbb 09-21-99  Added (RXD_ISR) command-traffic interrupt, restored
;                       SERIALIO publics
; v16740 dbb 12-05-99  Added some controls, commented out unused code
; v16743 dbb 12-13-99 Added HKPFULL and hkp changes only
; v16748 dbb 01-19-00 Added Memory Monitor hkp addresses
; v16771 dbb 02-03-00 Init code w/d state and reset counter added
; v16778 dbb 02-10-00 Filled unused space with jumps to trap
; v16796 dbb 03-02-00 Moved CMDIMAGE from RS25+24h to TS25+24h, much better
; v16803 dbb 03-07-00 Corrected PROJECT sense to COS=0, GALEX=1
; v16838 dbb 03-28-00 Now using 8k RAM for all cmd/hkp i/o
; v16845 dbb 04-03-00 Rewrote CDC commanding scheme to support differing
;                     layouts in Digitizer/TDC.  Pursuant to design goals,
;                     the TDC layout is specified in a table of commands
;                     that pairs equilvalent GALEX/COS Digitizer/TDC commands.
; v16848 dbb 04-12-00 Fix a few bugs:.
; v16854 dbb 04-14-00 Breadboard debug partial
; v16867 dbb 04-28-00 Special test command fcfc and partial Breadboard version.
; v16874 dbb 05-01-00 Upload to v16870, corrected an error in Digitizer Table
; v16876 dbb 05-02-00 Boot State Command Rejection Implemented
; v16880 dbb 05-04-00 Stim commands developed
; v16882 dbb 05-05-00 Memory mapping IVTs to 8000h, memory previously used
;                     as XDATA_AREA for MON51, now permanently retired.
; v16885 dbb 05-07-00 REORGANIZED! New memory and IVT layout, future
;                     uploads will not be compatable with older versions.
; v16894 dbb 05-15-00 REGION1 added to publics...
; v17000 dbb 05-22-00 Code Review Version
; v17026 dbb 06-13-00 Added LFHSTATE to map
;*****************************************************************************
;
;
;*** ASSEMBLY CONTROLS *******************************************************
; Assembly controls specify whether to include certain source-code segments,
; allowing the programmer to add/remove functionality as desired.
; A primary control is XSPEC, which is turned off for formal flight-software
; builds, but turned on for development use in the detector laboratory.
$SET (XSPEC)
;*****************************************************************************
; If the redundant command/housekeeping channel were to become a concern, we
; could use this control to ignore the second channel.
$SET (CHANNEL2)
;*****************************************************************************
; Partial refers to the use of UCA for storing the command/housekeeping buffers
; as would be required if the lower 8k RAM were missing, ala breadboard.
$SET (xPARTIAL)
;*****************************************************************************
; Degap means padding the code text with FF values so that all memory addresses
; are explicitly defined.  Not really a requirement of any kind, but more an
; aesthetic complete definition of the PROM.
$SET (xDEGAP)
;*****************************************************************************
; Debugging switch is generally used only for eningeering builds.  All debugging
; code may be removed before a flight code build.
$SET (xDEBUGGING)
;*****************************************************************************


;*** DIAGNOSTIC CODES ********************************************************
NULL_CMD     EQU       7FH    ; never used as a valid command
DIAG0000     EQU     5A00H    ; temporary diagnostic code
DIAG0001     EQU     5A01H    ; UPLOAD bad length
DIAG0002     EQU     5A02H    ; UPLOAD bad CRC
DIAG0003     EQU     5A03H    ; DUMP bad length
DIAG0004     EQU     5A04H    ; Wrong command MSB, should be 1
DIAG0005     EQU     5A05H    ; Command byte must have twin
DIAG0006     EQU     5A06H    ; Command Parameters must have complements
DIAG0007     EQU     5A07H    ; Stack Alarm
DIAG0008     EQU     5A08H    ; HV not armed
DIAG0009     EQU     5A09H    ; HV already armed
DIAG000A     EQU     5A0AH    ; HV already disarmed
DIAG000B     EQU     5A0BH    ; Motor not armed
DIAG000C     EQU     5A0CH    ; Motor already armed
DIAG000D     EQU     5A0DH    ; Motor already disarmed
DIAG000E     EQU     5A0EH    ; 28V actuators already armed
DIAG000F     EQU     5A0FH    ; 28V actuators already disarmed
DIAG0010     EQU     5A10H    ; 28V actuators not armed
DIAG0011     EQU     5A11H    ; CMD_ILLEGAL!
DIAG0012     EQU     5A12H    ; Bit alignment screw-up (linker)
DIAG0013     EQU     5A13H    ; Command did not complete execution
DIAG0014     EQU     5A14H    ; Function not implemented!
DIAG0015     EQU     5A15H    ; Latch already set, command ignored
DIAG0016     EQU     5A16H    ; Spike Warning AuxI
DIAG0017     EQU     5A17H    ; retired
DIAG0018     EQU     5A18H    ; Lower Code RAM CRC changed!
DIAG0019     EQU     5A19H    ; Upper Code RAM CRC changed.
DIAG001A     EQU     5A1AH    ; Something in ROM 0-3FFF changed.
DIAG001B     EQU     5A1BH    ; First watchdog reset (expected)
DIAG001C     EQU     5A1CH    ; Second watchdog reset (unexpected)
DIAG001D     EQU     5A1DH    ; Watchdog reset test failed (unexpected)
DIAG001E     EQU     5A1EH    ; Hardware self-reset failed (unexpected)
DIAG001F     EQU     5A1FH    ; Boot Violation
DIAG0020     EQU     5A20H    ; CRC changed in Mask A
DIAG0021     EQU     5A21H    ; CRC changed in Mask B
DIAG0022     EQU     5A22H    ; SAA shutdown activated
DIAG0023     EQU     5A23H    ; SAA shutdown completed, restored
DIAG0024     EQU     5A24H    ; retired
DIAG0025     EQU     5A25H    ; time out detected!
DIAG0026     EQU     5A26H    ; AUX_I_MON exceeds DOOR_IMAX
DIAG0027     EQU     5A27H    ; retired, dbb 12-23-98
DIAG0028     EQU     5A28H    ; retired, dbb 12-23-98
DIAG0029     EQU     5A29H    ; Breadboard detected
DIAG002A     EQU     5A2AH    ; HV_I_MAX exceeded on HV_A, powered off
DIAG002B     EQU     5A2BH    ; HV_I_MAX exceeded on HV_B, powered off
DIAG002C     EQU     5A2CH    ; Trap! Wild code detected
DIAG002D     EQU     5A2DH    ; Mask_Select Left On!
DIAG002E     EQU     5A2EH    ; AUX_I_MAX exceeded, HV powered off.
DIAG002F     EQU     5A2FH    ; Attempt to execute operate code while in boot
DIAG0030     EQU     5A30h    ; PMON limit violation

;*****************************************************************************
;*** MEMORY MAPPED I/O *******************************************************
;*****************************************************************************
LEDS         EQU     200Dh    ; bank of LEDs on prototype board

; HV DACs named after Interface Board page 1/7, U12, pins
;dbb 12-24-98;DAC_SPACE    EQU     4100h    ;Digital-to-Analog, base of 8
VSETA        EQU     4401H    ; pin 1
VSETB        EQU     4403H    ; pin 23
VMAXA        EQU     4400H    ; pin 2
VMAXB        EQU     4402H    ; pin 24

CONTROLS1    EQU     4200h    ;Board C, UNLOCK required

HV_ENA_1     EQU     CONTROLS1+01H ;RP1.16
HV_ENA_2     EQU     CONTROLS1+02H ;RP1.15
IP_ON        EQU     CONTROLS1+04H ;RP1.14
QENABLE      EQU     CONTROLS1+08H ;RP1.13 now known as PROM_ON~
OVERRIDE     EQU     CONTROLS1+10H ;RP1.12
;ACT_A_ON     EQU     CONTROLS1+20H ;RP1.11
;ACT_B_ON     EQU     CONTROLS1+40H ;RP1.10
MOTOR_ON     EQU     CONTROLS1+80H ;RP1.9


CONTROLS2    EQU     4300h    ;Board C

IP_A_ON      EQU     CONTROLS2+01H ;RP2.16
IP_B_ON      EQU     CONTROLS2+02H ;RP2.15
SCRUB_ON     EQU     CONTROLS2+04H ;RP2.14
STIM_ON      EQU     CONTROLS2+08H ;RP2.13
MA_CNTRL     EQU     CONTROLS2+20H ;RP2.11
MB_CNTRL     EQU     CONTROLS2+40H ;RP2.10
;CT_ENA      EQU     CONTROLS2+80H ;RP2.9

AUX_PWR_ENA  EQU     CONTROLS1+04H ;

sLFRACT1     EQU     CONTROLS2+02H ;RP2.9
sLFRACT2     EQU     CONTROLS2+04H ;RP2.9
sLFRACTEN    EQU     CONTROLS2+10H ;RP2.9


ADC_SPACE    EQU     4700h    ;Analog-to-Digital, base of 8

RXD_HARDWARE EQU     5000h    ; Cmd data base register
TXD_HARDWARE EQU     5000h    ; Cmd data base register

COUNTERS_A   EQU     6000h    ;base of 8 counters for Digitizer A
COUNTERS_B   EQU     6100h    ;base of 8 counters for Digitizer B
PH_SLICE_0   EQU     6200h    ; Pulse Height Histogram Side A

; These data buffers are stuck here at specific addresses in upper code space.
;  With the monitor removed, the code starts at D6D0.
;  So we have just enough space for three data buffers for current sampling.
;  dbb 12-24-98
SAMPHVIA     EQU     0C000h   ; length 400h for 1024 8-bit samples
SAMPHVIB     EQU     0C800h   ; length 400h for 1024 8-bit samples
SAMPAUXI     EQU     0D000h   ; length 400h for 1024 8-bit samples

; Buffer for storing timestamps for samples
; SAMPTIME controlled-out dbb 12-5-99
$IF SAMPLETIMESTAMPS
SAMPTIME     EQU     08800h   ; length 400h for 1024 8-bit samples
$ENDIF
HISTHVIA     EQU     SAMPHVIA+400h ; length 200h for 256 16-bit sample bins
HISTHVIB     EQU     SAMPHVIB+400h ; length 200h for 256 16-bit sample bins
HISTAUXI     EQU     SAMPAUXI+400h ; length 200h for 256 16-bit sample bins

;*****************************************************************************
; Addresses of the interrupt service vectors located in 32k RAM.
; Use of these addressed must be preceded by the loading of IVT code at
; the specified addresses.
vRXD0ISR     EQU     8000h
vT0_ISR      EQU     8003h
vRXD1ISR     EQU     8006h
vT1_ISR      EQU     8009h
vSER_ISR     EQU     800Ch
vT2_ISR      EQU     800Fh
vPCA_ISR     EQU     8012h
vAUX_ISR     EQU     8015h

;*** COMMAND BUFFER **********************************************************
$IF PARTIAL
RS00            EQU 0e000h        ; base receive address
$ELSE
RS00            EQU 00000h        ; base receive address
$ENDIF

;-----------------------------------------------------------------------------
RS01            EQU RS00+40h     ; receive subaddress 1, data
RS17            EQU RS00+440h    ; receive subaddress 17, commands
RS25            EQU RS00+640h    ; receive subaddress 17, commands
RS26            EQU RS00+680h    ; receive subaddress 17, commands

;*** HOUSEKEEPING ************************************************************
$IF PARTIAL
TS00            EQU 0f000h    ; base transmit address
$ELSE
TS00            EQU 01000h    ; base transmit address
$ENDIF

;-----------------------------------------------------------------------------
TS01            EQU TS00+0040h   ; transmit subaddress 1, data
TS17            EQU TS00+0440h   ; Dest for PH slice 0
TS25            EQU TS00+0640h   ; Destination for counters
TS26            EQU TS00+0680h   ; Destination for counters
TS28            EQU TS00+0700h   ; Dest for Essential Monitors
TS30            EQU TS00+0780h   ; for DIAGNOSTIC reporting
TS31            EQU TS00+07C0h   ; undefined

;-----------------------------------------------------------------------------
STAPACKETTIMESTAMP EQU TS00+040h       ; Save timer value - hkpupdate dbb debug 4-1-00
;-----------------------------------------------------------------------------
;GDGPH0          EQU TS00+0440h ; 0440 pulse-height histogram bin
                               ; 0442 pulse-height histogram bin
                               ; 0444 pulse-height histogram bin
                               ; 0446 pulse-height histogram bin
                               ; 0448 pulse-height histogram bin
                               ; 044A pulse-height histogram bin
                               ; 044C pulse-height histogram bin
                               ; 044E pulse-height histogram bin
                               ; 0450 pulse-height histogram bin
                               ; 0452 pulse-height histogram bin
                               ; 0454 pulse-height histogram bin
                               ; 0456 pulse-height histogram bin
                               ; 0458 pulse-height histogram bin
                               ; 045A pulse-height histogram bin
                               ; 045C pulse-height histogram bin
                               ; 045E pulse-height histogram bin
                               ; 0460 pulse-height histogram bin
                               ; 0462 pulse-height histogram bin
                               ; 0464 pulse-height histogram bin
                               ; 0466 pulse-height histogram bin
                               ; 0468 pulse-height histogram bin
                               ; 046A pulse-height histogram bin
                               ; 046C pulse-height histogram bin
                               ; 046E pulse-height histogram bin
                               ; 0470 pulse-height histogram bin
                               ; 0472 pulse-height histogram bin
                               ; 0474 pulse-height histogram bin
                               ; 0476 pulse-height histogram bin
                               ; 0478 pulse-height histogram bin
                               ; 047A pulse-height histogram bin
                               ; 047C pulse-height histogram bin
                               ; 047E pulse-height histogram bin
;GDGPH1          EQU TS00+0480h ;      pulse-height histogram bin
                               ; 0482 pulse-height histogram bin
                               ; 0484 pulse-height histogram bin
                               ; 0486 pulse-height histogram bin
                               ; 0488 pulse-height histogram bin
                               ; 048A pulse-height histogram bin
                               ; 048C pulse-height histogram bin
                               ; 048E pulse-height histogram bin
                               ; 0490 pulse-height histogram bin
                               ; 0492 pulse-height histogram bin
                               ; 0494 pulse-height histogram bin
                               ; 0496 pulse-height histogram bin
                               ; 0498 pulse-height histogram bin
                               ; 049A pulse-height histogram bin
                               ; 049C pulse-height histogram bin
                               ; 049E pulse-height histogram bin
                               ; 04A0 pulse-height histogram bin
                               ; 04A2 pulse-height histogram bin
                               ; 04A4 pulse-height histogram bin
                               ; 04A6 pulse-height histogram bin
                               ; 04A8 pulse-height histogram bin
                               ; 04AA pulse-height histogram bin
                               ; 04AC pulse-height histogram bin
                               ; 04AE pulse-height histogram bin
                               ; 04B0 pulse-height histogram bin
                               ; 04B2 pulse-height histogram bin
                               ; 04B4 pulse-height histogram bin
                               ; 04B6 pulse-height histogram bin
                               ; 04B8 pulse-height histogram bin
                               ; 04BA pulse-height histogram bin
                               ; 04BC pulse-height histogram bin
                               ; 04BE pulse-height histogram bin
;GDGPH2          EQU TS00+04C0h ;      pulse-height histogram bin
                               ; 04C2 pulse-height histogram bin
                               ; 04C4 pulse-height histogram bin
                               ; 04C6 pulse-height histogram bin
                               ; 04C8 pulse-height histogram bin
                               ; 04CA pulse-height histogram bin
                               ; 04CC pulse-height histogram bin
                               ; 04CE pulse-height histogram bin
                               ; 04D0 pulse-height histogram bin
                               ; 04D2 pulse-height histogram bin
                               ; 04D4 pulse-height histogram bin
                               ; 04D6 pulse-height histogram bin
                               ; 04D8 pulse-height histogram bin
                               ; 04DA pulse-height histogram bin
                               ; 04DC pulse-height histogram bin
                               ; 04DE pulse-height histogram bin
                               ; 04E0 pulse-height histogram bin
                               ; 04E2 pulse-height histogram bin
                               ; 04E4 pulse-height histogram bin
                               ; 04E6 pulse-height histogram bin
                               ; 04E8 pulse-height histogram bin
                               ; 04EA pulse-height histogram bin
                               ; 04EC pulse-height histogram bin
                               ; 04EE pulse-height histogram bin
                               ; 04F0 pulse-height histogram bin
                               ; 04F2 pulse-height histogram bin
                               ; 04F4 pulse-height histogram bin
                               ; 04F6 pulse-height histogram bin
                               ; 04F8 pulse-height histogram bin
                               ; 04FA pulse-height histogram bin
                               ; 04FC pulse-height histogram bin
                               ; 04FE pulse-height histogram bin
;GDGPH3          EQU TS00+0500h ;      pulse-height histogram bin
                               ; 0502 pulse-height histogram bin
                               ; 0504 pulse-height histogram bin
                               ; 0506 pulse-height histogram bin
                               ; 0508 pulse-height histogram bin
                               ; 050A pulse-height histogram bin
                               ; 050C pulse-height histogram bin
                               ; 050E pulse-height histogram bin
                               ; 0510 pulse-height histogram bin
                               ; 0512 pulse-height histogram bin
                               ; 0514 pulse-height histogram bin
                               ; 0516 pulse-height histogram bin
                               ; 0518 pulse-height histogram bin
                               ; 051A pulse-height histogram bin
                               ; 051C pulse-height histogram bin
                               ; 051E pulse-height histogram bin
                               ; 0520 pulse-height histogram bin
                               ; 0522 pulse-height histogram bin
                               ; 0524 pulse-height histogram bin
                               ; 0526 pulse-height histogram bin
                               ; 0528 pulse-height histogram bin
                               ; 052A pulse-height histogram bin
                               ; 052C pulse-height histogram bin
                               ; 052E pulse-height histogram bin
                               ; 0530 pulse-height histogram bin
                               ; 0532 pulse-height histogram bin
                               ; 0534 pulse-height histogram bin
                               ; 0536 pulse-height histogram bin
                               ; 0538 pulse-height histogram bin
                               ; 053A pulse-height histogram bin
                               ; 053C pulse-height histogram bin
                               ; 053E pulse-height histogram bin
;XDGPH0          EQU TS00+0540h ; 0540 pulse-height histogram bin
                               ; 0542 pulse-height histogram bin
                               ; 0544 pulse-height histogram bin
                               ; 0546 pulse-height histogram bin
                               ; 0548 pulse-height histogram bin
                               ; 054A pulse-height histogram bin
                               ; 054C pulse-height histogram bin
                               ; 054E pulse-height histogram bin
                               ; 0550 pulse-height histogram bin
                               ; 0552 pulse-height histogram bin
                               ; 0554 pulse-height histogram bin
                               ; 0556 pulse-height histogram bin
                               ; 0558 pulse-height histogram bin
                               ; 055A pulse-height histogram bin
                               ; 055C pulse-height histogram bin
                               ; 055E pulse-height histogram bin
                               ; 0560 pulse-height histogram bin
                               ; 0562 pulse-height histogram bin
                               ; 0564 pulse-height histogram bin
                               ; 0566 pulse-height histogram bin
                               ; 0568 pulse-height histogram bin
                               ; 056A pulse-height histogram bin
                               ; 056C pulse-height histogram bin
                               ; 056E pulse-height histogram bin
                               ; 0570 pulse-height histogram bin
                               ; 0572 pulse-height histogram bin
                               ; 0574 pulse-height histogram bin
                               ; 0576 pulse-height histogram bin
                               ; 0578 pulse-height histogram bin
                               ; 057A pulse-height histogram bin
                               ; 057C pulse-height histogram bin
                               ; 057E pulse-height histogram bin
;XDGPH1          EQU TS00+0580h ;      pulse-height histogram bin
                               ; 0582 pulse-height histogram bin
                               ; 0584 pulse-height histogram bin
                               ; 0586 pulse-height histogram bin
                               ; 0588 pulse-height histogram bin
                               ; 058A pulse-height histogram bin
                               ; 058C pulse-height histogram bin
                               ; 058E pulse-height histogram bin
                               ; 0590 pulse-height histogram bin
                               ; 0592 pulse-height histogram bin
                               ; 0594 pulse-height histogram bin
                               ; 0596 pulse-height histogram bin
                               ; 0598 pulse-height histogram bin
                               ; 059A pulse-height histogram bin
                               ; 059C pulse-height histogram bin
                               ; 059E pulse-height histogram bin
                               ; 05A0 pulse-height histogram bin
                               ; 05A2 pulse-height histogram bin
                               ; 05A4 pulse-height histogram bin
                               ; 05A6 pulse-height histogram bin
                               ; 05A8 pulse-height histogram bin
                               ; 05AA pulse-height histogram bin
                               ; 05AC pulse-height histogram bin
                               ; 05AE pulse-height histogram bin
                               ; 05B0 pulse-height histogram bin
                               ; 05B2 pulse-height histogram bin
                               ; 05B4 pulse-height histogram bin
                               ; 05B6 pulse-height histogram bin
                               ; 05B8 pulse-height histogram bin
                               ; 05BA pulse-height histogram bin
                               ; 05BC pulse-height histogram bin
                               ; 05BE pulse-height histogram bin
;XDGPH2          EQU TS00+05C0h ;      pulse-height histogram bin
                               ; 05C2 pulse-height histogram bin
                               ; 05C4 pulse-height histogram bin
                               ; 05C6 pulse-height histogram bin
                               ; 05C8 pulse-height histogram bin
                               ; 05CA pulse-height histogram bin
                               ; 05CC pulse-height histogram bin
                               ; 05CE pulse-height histogram bin
                               ; 05D0 pulse-height histogram bin
                               ; 05D2 pulse-height histogram bin
                               ; 05D4 pulse-height histogram bin
                               ; 05D6 pulse-height histogram bin
                               ; 05D8 pulse-height histogram bin
                               ; 05DA pulse-height histogram bin
                               ; 05DC pulse-height histogram bin
                               ; 05DE pulse-height histogram bin
                               ; 05E0 pulse-height histogram bin
                               ; 05E2 pulse-height histogram bin
                               ; 05E4 pulse-height histogram bin
                               ; 05E6 pulse-height histogram bin
                               ; 05E8 pulse-height histogram bin
                               ; 05EA pulse-height histogram bin
                               ; 05EC pulse-height histogram bin
                               ; 05EE pulse-height histogram bin
                               ; 05F0 pulse-height histogram bin
                               ; 05F2 pulse-height histogram bin
                               ; 05F4 pulse-height histogram bin
                               ; 05F6 pulse-height histogram bin
                               ; 05F8 pulse-height histogram bin
                               ; 05FA pulse-height histogram bin
                               ; 05FC pulse-height histogram bin
                               ; 05FE pulse-height histogram bin
;XDGPH3          EQU TS00+0600h ;      pulse-height histogram bin
                               ; 0602 pulse-height histogram bin
                               ; 0604 pulse-height histogram bin
                               ; 0606 pulse-height histogram bin
                               ; 0608 pulse-height histogram bin
                               ; 060A pulse-height histogram bin
                               ; 060C pulse-height histogram bin
                               ; 060E pulse-height histogram bin
                               ; 0610 pulse-height histogram bin
                               ; 0612 pulse-height histogram bin
                               ; 0614 pulse-height histogram bin
                               ; 0616 pulse-height histogram bin
                               ; 0618 pulse-height histogram bin
                               ; 061A pulse-height histogram bin
                               ; 061C pulse-height histogram bin
                               ; 061E pulse-height histogram bin
                               ; 0620 pulse-height histogram bin
                               ; 0622 pulse-height histogram bin
                               ; 0624 pulse-height histogram bin
                               ; 0626 pulse-height histogram bin
                               ; 0628 pulse-height histogram bin
                               ; 062A pulse-height histogram bin
                               ; 062C pulse-height histogram bin
                               ; 062E pulse-height histogram bin
                               ; 0630 pulse-height histogram bin
                               ; 0632 pulse-height histogram bin
                               ; 0634 pulse-height histogram bin
                               ; 0636 pulse-height histogram bin
                               ; 0638 pulse-height histogram bin
                               ; 063A pulse-height histogram bin
                               ; 063C pulse-height histogram bin
                               ; 063E pulse-height histogram bin
tLFDERR         EQU TS00+0640h ;      HST error codes
                               ; 0642 HST error codes
                               ; 0644 HST error codes
                               ; 0646 HST error codes
tLFDERRP        EQU TS00+0648h ;      HST error parameter
                               ; 064A HST error parameter
                               ; 064C HST error parameter
                               ; 064E HST error parameter
                               ; 0650 HST error parameter
                               ; 0652 HST error parameter
                               ; 0654 HST error parameter
                               ; 0656 HST error parameter
GDSBITS4        EQU TS00+0658h ; *G*
                               ; 065A
                               ; 065C
                               ; 065E
                               ; 0660
                               ; 0662
;GDDCBUF         EQU TS00+0664h        ; CMDIMAGE
CMDIMAGE        EQU TS00+0664h   ; image of command buffer LFDCBUF
SERIALN         EQU TS00+0666h   ; Command serial number
RS17_PAR0       EQU CMDIMAGE+08h ; Parameter 0 for command
RS17_PAR1       EQU CMDIMAGE+0Ch ; Parameter 1 for command
RS17_PAR2       EQU CMDIMAGE+10h ; Parameter 2 for command, usually CRC
RS17_PAR3       EQU CMDIMAGE+14h ; Parameter 3 for command
RS17_PAR4       EQU CMDIMAGE+18h ; Parameter 4 for command
                               ; 067C
                               ; 067E
tDCTIMEL        EQU TS00+0680h ; *G*
tDCTIMEH        EQU TS00+0682h ; *G*
                               ; 0684
                               ; 0686
                               ; 0688
                               ; 068A
                               ; 068C
                               ; 068E
                               ; 0690
                               ; 0692
tDCDECL         EQU TS00+0694h
tCDEA           EQU TS00+0694H  ; Digitized events
tDCDECH         EQU TS00+0696h ; *G*
tCDEB           EQU TS00+0698H  ;
                               ; 069A
                               ; 069C
SA_MON          EQU TS00+069Ch ; moved from 6A4 for CRP development, dbb 6-21-00
                               ; 069E
                               ; 06A0
SB_MON          EQU TS00+06A0h ; moved from 6A8 for CRP development, dbb 6-21-00
                               ; 06A2
;tDCTECL         EQU TS00+06A4h
tCASA           EQU TS00+06A4H  ; Autonomous shutdown
tDCTECH         EQU TS00+06A6h ; *G*
;SB_MON          EQU TS00+06A8h
tCASB           EQU TS00+06A8H  ;
tDCFECL         EQU TS00+06ACh
tCFEA           EQU TS00+06ACH  ; Fast events
tDCFECH         EQU TS00+06AEh ; *G*
tCFEB           EQU TS00+06B0H  ;
                               ; 06B2
                               ; 06B4
                               ; 06B6
                               ; 06B8
                               ; 06BA
tLFGSHFAX       EQU TS00+06BCh
tDGBOFFX        EQU TS00+06BCh
tXSHIFTA        EQU TS00+06BCh  ; select amon XSHIFT
tLFGSTRAX       EQU TS00+06BDh
tDGBSCLX        EQU TS00+06BDh
tXSTRETA        EQU TS00+06BDh  ; select amon XSTRETCH
tDGEOFFX        EQU TS00+06BEh
tLFGSHFBX       EQU TS00+06BEh
tXSHIFTB        EQU TS00+06BEh  ; select amon XSHIFT
tLFGSTRBX       EQU TS00+06BFh
tDGESCLX        EQU TS00+06BFh
tXSTRETB        EQU TS00+06BFh  ; select amon XSTRETCH
tDTDET          EQU TS00+06C0h
LFTDVAA         EQU TS00+06C0h  ; Det Vacuum Assy A Temp
;tDET_TEMP       EQU TS00+06C0h  ; detector temperature
LFTACT          EQU TS00+06C1h  ; Actuator temp
;tDOOR_TEMP      EQU TS00+06C1h  ; door temperature
LFTHVFM         EQU TS00+06C2h  ; HVFM Temp
;tFLT_TEMP       EQU TS00+06C2h  ; HV filter temperature
;tDTHVPS         EQU TS00+06C3h
LFTHVPS         EQU TS00+06C3h  ; HVPS Temp
tHV_TEMP        EQU TS00+06C3h  ; HV module temperature
LFTIP           EQU TS00+06C4h  ; Ion Pump Temp
tIP_TEMP        EQU TS00+06C4h  ; Ion pump assembly temperature
LFTDVAB         EQU TS00+06C5h  ; Det Vacuum Assy B Temp
tLAMP_TEMP      EQU TS00+06C5h  ; lamp assembly temperature
tDTAMPA         EQU TS00+06C6h
LFTAMPA         EQU TS00+06C6h  ; Amp A Temp
tAMP_A_TEMP     EQU TS00+06C6h  ; Amplifier A temperature
tDTAMPB         EQU TS00+06C7h
LFTAMPB         EQU TS00+06C7h  ; Amp B Temp
tAMP_B_TEMP     EQU TS00+06C7h  ; Amplifier B temperature
;tDTTDC          EQU TS00+06C8h
LFTTDCA         EQU TS00+06C8h  ; TDC A Temp
;tTDC_A_TEMP     EQU TS00+06C8h  ; TDC A temperature
LFTTDCB         EQU TS00+06C9h  ; TDC B Temp
tTDC_B_TEMP     EQU TS00+06C9h  ; TDC B temperature
tDTLVPS         EQU TS00+06CAh
LFTLVPS               EQU TS00+06CAh  ; LVPS Temp
tPC_TEMP        EQU TS00+06CAh  ; Power COntroller temperature
tDTDIB          EQU TS00+06CBh
LFTDCE          EQU TS00+06CBh  ; DCE Temp
tDP_TEMP        EQU TS00+06CBh  ; DPU temperature
tDSFHV          EQU TS00+06CCh
LFHFAN          EQU TS00+06CCh  ; FHV Status Analog
tF_STAT         EQU TS00+06CCh  ; Normal operation indictor for MCP back face HV, DPU +5V
tDVP5D          EQU TS00+06CDh
tDP5V           EQU TS00+06CDh  ; +5V monitor
LFVP5DC         EQU TS00+06CDh  ; DCE-C +5V
tDVP5DB         EQU TS00+06CEh
tIP_1_IMON      EQU TS00+06CEh  ; Ion Pump 1 bias current monitor
tDTCON          EQU TS00+06CFh
tIP_2_IMON      EQU TS00+06CFh  ; Ion Pump 2 bias current monitor
tDVP21H         EQU TS00+06D0h
tLFVP21D        EQU TS00+06D0h  ; +21 Volt monitor
tUNUSED11       EQU TS00+06D1h  ; was Voltage monitor for stim+scrub supply
tDHIMON         EQU TS00+06D2h
LFHIMONA        EQU TS00+06D2h  ; HV Current A
tHI_MON_A       EQU TS00+06D2h  ; MCP bias current on side A
LFHIMONB        EQU TS00+06D3h  ; HV Current B
tHI_MON_B       EQU TS00+06D3h  ; MCP bias current on side B
tDHVMON         EQU TS00+06D4h
LFHVMONA        EQU TS00+06D4h  ; HV Output Volts A
tHV_MON_A       EQU TS00+06D4h  ; MCP entrance face HV monitors
LFHVMONB        EQU TS00+06D5h  ; HV Output Volts B
tHV_MON_B       EQU TS00+06D5h  ; MCP entrance face HV monitors
tQ_STAT_A       EQU TS00+06D6h  ; grid HV side A
LFHQANA               EQU TS00+06D6h  ; QHVA status analog
tQ_STAT_B       EQU TS00+06D7h  ; grid HV side B
LFHQANB               EQU TS00+06D7h  ; QHVB status analog
tDVP15T         EQU TS00+06D8h
tTDC_Ap15MON    EQU TS00+06D8h  ; TDC +15V LV supply monitors, side A
tTDC_Bp15MON    EQU TS00+06D9h  ; TDC +15V LV supply monitors, side B
tDVP6T          EQU TS00+06DAh
tTDC_Ap5MON     EQU TS00+06DAh  ; TDC +5V LV supply monitors, side A
tTDC_Bp5MON     EQU TS00+06DBh  ; TDC +5V LV supply monitors, side B
tDVM15T         EQU TS00+06DCh
tTDC_Am15MON    EQU TS00+06DCh  ; TDC -15V LV supply monitors, side A
tTDC_Bm15MON    EQU TS00+06DDh  ; TDC -15V LV supply monitors, side B
tDVM7T          EQU TS00+06DEh
tTDC_Am5MON     EQU TS00+06DEh  ; TDC -5V LV supply monitors, side A
tTDC_Bm5MON     EQU TS00+06DFh  ; TDC -5V LV supply monitors, side B
tDVP15D         EQU TS00+06E0h
LFVP15D         EQU TS00+06E0h  ; DCE +15V
tDP_p15V        EQU TS00+06E0h  ; DPU +15V monitor
tDVM15D         EQU TS00+06E1h
LFVM15D               EQU TS00+06E1h  ; DCE -15V
tDP_m15V        EQU TS00+06E1h  ; DPU -15V monitor
tDHVDAC         EQU TS00+06E2h
LFHSETA               EQU TS00+06E2h  ; HV Command Level A
tHV_A_DAC       EQU TS00+06E2h  ; Value for HV A setting
LFHSETB               EQU TS00+06E3h  ; HV Command Level B
tHV_B_DAC       EQU TS00+06E3h  ; Value for HV B setting
tSTATUS_BITS2   EQU TS00+06E4h  ; 27 19 STATUS_BITS2
tLFGUQTAX       EQU TS00+06E6h
tDGUQT          EQU TS00+06E6h
tUPR_Q_THR_A    EQU TS00+06E6h  ; QUP: TDC upper charge (Y) thresholds side A
tLFGUQTBX       EQU TS00+06E7h
tUPR_Q_THR_B    EQU TS00+06E7h  ; QUP: TDC upper charge (Y) thresholds side B
tLFGBWKAX       EQU TS00+06E8h
tDGBWKX         EQU TS00+06E8h
tBEG_WLK_A      EQU TS00+06E8h  ; BWALK: TDC threshold side A
tLFGBWKBX       EQU TS00+06E9h
tBEG_WLK_B      EQU TS00+06E9h  ; BWALK: TDC threshold side B
tDGEWKX         EQU TS00+06EAh
tLFGEWKAX       EQU TS00+06EAh
tEND_WLK_A      EQU TS00+06EAh  ; EWALK: TDC threshold side A
tLFGEWKBX       EQU TS00+06EBh
tEND_WLK_B      EQU TS00+06EBh  ; EWALK: TDC threshold side B
;tBSL_Q_THR_A    EQU TS00+06ECh  ; BLTHR: TDC threshold side A
;tBSL_Q_THR_B    EQU TS00+06EDh  ; BLTHR: TDC threshold side B
tLFGLQTAX       EQU TS00+06EEh
tDGLQT          EQU TS00+06EEh
tLWR_Q_THR_A    EQU TS00+06EEh  ; QLO: TDC threshold side A
tLFGLQTBX       EQU TS00+06EFh
tLWR_Q_THR_B    EQU TS00+06EFh  ; QLO: TDC threshold side B
tLFGTTAX        EQU TS00+06F0h
tDGTTX          EQU TS00+06F0h
tLWR_T_THR_A    EQU TS00+06F0h  ; TTHR: TDC threshold side A
tLFGTTBX        EQU TS00+06F1h
tLWR_T_THR_B    EQU TS00+06F1h  ; TTHR: TDC threshold side B
tSTATUS_BITS0   EQU TS00+06F2h  ; STATUS_BITS0 and STATUS_BITS1, misc bits
                               ; 06F4
tUpperBITS1     EQU TS00+06F5h  ; 27 27, high byte, get DOOR_POS_A, D3
tCRC_Mask_A     EQU TS00+06F6h  ; 27 28, Mask A CRC
tCRC_Mask_B     EQU TS00+06F8h  ; 27 29, Mask B CRC
GDMRAM          EQU TS00+06FAh
tCRC_RAM        EQU TS00+06FAh  ; RAM CRC
GDMROM          EQU TS00+06FCh
tCRC_ROM        EQU TS00+06FCh  ; ROM CRC
GDDSWVER        EQU TS00+06FEh
tDP_VERSION     EQU TS00+06FEh  ; DPU software version
GDCPKTL         EQU TS00+0700h
GDCPKTH         EQU TS00+0702h
GDDLSTC         EQU TS00+0704h
tCMD_R          EQU TS00+0704h  ; Command 1 response = CMD    CMD_R to...
LFHSTATE        EQU TS00+0705h
GDGREF          EQU TS00+0706h
tVREFA          EQU TS00+0706h  ; VREF A: Reference voltages for digitizer A
tVREFB          EQU TS00+0707h  ; VREF B: Reference voltages for digitizer B
tDIAG0          EQU TS00+0708h  ; 28 5 DIAG0, latest diagnostic code
tDIAG1          EQU TS00+0709h  ; 28 5 DIAG1, next latest diagnostic code
DOOR_IMAX       EQU TS00+070Ah
HV_IMAX         EQU TS00+070Bh
tDHVILIM        EQU TS00+070Bh
tDDCMDX         EQU TS00+070Ch
tDP_CMD_C       EQU TS00+070Ch  ; DPU commands counter executed
tDPCNT          EQU TS00+070Eh
tSAA_MAX_A      EQU TS00+070Eh  ; 28 08, default count limits A trigger level
tDVPMON         EQU TS00+0710h
tPMON           EQU TS00+0710h  ; Input power monitor
LFVPMON         EQU TS00+0710h  ; LVPC Input Power
tDIAG2          EQU TS00+0711h  ; 28 9+ DIAG2
tSTATUS_BITS3   EQU TS00+0712h  ; STIM_ON_A, STIM_ON_B, STIM_MODE,DOOR_POS
tDOOR_POS_A     EQU TS00+0713h  ; Analog door position
LFRACTAN        EQU TS00+0714h  ; Actuator analog status
tACT_STAT       EQU TS00+0714h  ; Voltage monitor for actuators A+B
LFRMTRAN        EQU TS00+0715h  ; Door motor analog monitor
tMOTOR_STAT     EQU TS00+0715h  ; Voltage monitor for motor drive
LFRAXI          EQU TS00+0716h  ; Aux power supply current
tAUX_MON        EQU TS00+0716h  ; Current monitor for Aux power
LFRAXAN               EQU TS00+0717h  ; Aux status analog
tAUX_STAT       EQU TS00+0717h  ; Voltage monitor for 28V Aux power oscillator
tDDCMDR         EQU TS00+0718h
tDP_CMD_R       EQU TS00+0718h  ; DPU Commands received
tDMSAV          EQU TS00+071Ah
tSAVE_CRC       EQU TS00+071Ah  ; Last CRC calculated
;tDPINT          EQU TS00+071Ch
tLFPINTA        EQU TS00+071Ch  ; 28 15+ SAA_INT_TIME, overloaded A & B
tSAA_INT_TIME   EQU TS00+071Dh  ; 28 15+ SAA_INT_TIME, overloaded A & B
tSAA_MAX_B      EQU TS00+071Eh  ; 28 16 default count limits B
tDHVLO          EQU TS00+0720h
tSAA_HV_A       EQU TS00+0720h  ; SAA_HV_A
tSAA_HV_B       EQU TS00+0721h  ; SAA_HV_B
tDPTIME         EQU TS00+0722h
tHV_AUTO_R      EQU TS00+0722h  ; Number of seconds(?) to hold HV Auto Reduce
tDHVNOM         EQU TS00+0724h
LFHVNOMA        EQU TS00+0724h  ; Value for HV A DAC setting
LFHVNOMB        EQU TS00+0725h  ; Value for HV A DAC setting
tDHVMAX         EQU TS00+0726h
LFHVMAXA        EQU TS00+0726h  ; HV Command Level maximum A
tHV_A_MAX       EQU TS00+0726h  ; Value for HV A MAX setting
LFHVMAXB        EQU TS00+0727h  ; HV Command Level maximum B
tHV_B_MAX       EQU TS00+0727h  ; Value for HV B MAX setting
tLFPINTB        EQU TS00+0728h  ; 28 15+ SAA_INT_TIME, overloaded A & B
tMUXBITS        EQU TS00+072Ah  ;
GDSBITS6        EQU TS00+072Ch
tC1BITS         EQU TS00+072Ch  ;
tC2BITS         EQU TS00+072Dh  ;
tDGSTIM         EQU TS00+072Eh
tLFDPERF        EQU TS00+0730h
                               ; 0732
tDDPEEK         EQU TS00+0734h
tPOINTMON       EQU TS00+0734h  ; POINTMON
LFRPOS          EQU TS00+0735h  ; Door position 0..255
tDDINT          EQU TS00+0736h
tLFDMEXTR       EQU TS00+0736h  ; memory monitor external/internal select bits
tDDCOD          EQU TS00+0737h
tLFDMDATA       EQU TS00+0737h  ; memory monitor data/code select bits
tDDMON          EQU TS00+0738h
tLFDMONS        EQU TS00+0738h  ; memory monitor values
tDDMADD         EQU TS00+0740h
tLFDMADD        EQU TS00+0740h  ; memory monitor addresses
tLFGBWKAY       EQU TS00+0750h
tDGBWKY         EQU TS00+0750h
tDGEWKY         EQU TS00+0751h
tLFGEWKAY       EQU TS00+0751h
tLFGBWKBY       EQU TS00+0752h
tLFGEWKBY       EQU TS00+0753h
                               ; 0754
tDOORTIMER      EQU TS00+0754h ; new as of 6-1-00
                               ; 0756
tDUMMY          EQU TS00+0756h ; a place-holder for as-yet undefined hkp items
                               ; 0758
tDSBITS5        EQU TS00+075Ah
                               ; 075C
tDGTTY          EQU TS00+075Eh
tLFGTTAY        EQU TS00+075Eh
tLFGTTBY        EQU TS00+075Fh
tLFGSHFAY       EQU TS00+0760h
tDGBOFFY        EQU TS00+0760h
tDGBSCLY        EQU TS00+0761h
tLFGSTRAY       EQU TS00+0761h
tDGEOFFY        EQU TS00+0762h
tLFGSHFBY       EQU TS00+0762h
tLFGSTRBY       EQU TS00+0763h
tDGESCLY        EQU TS00+0763h
                               ; 0764
tLFGLQTAY       EQU TS00+0766h
tLFGLQTBY       EQU TS00+0767h
tLFGUQTAY       EQU TS00+0768h
tLFGUQTBY       EQU TS00+0769h
                               ; 076A
                               ; 076C
                               ; 076E
                               ; 0770
tLED_IMAGE      EQU TS00+0772h  ; copy of LED settings
tDHRAMPT        EQU TS00+0774h       ; *G*
tDIAG3          EQU TS00+0776h  ; DIAG3
tDIAG4          EQU TS00+0777h  ; DIAG4
tDMU7           EQU TS00+0778h
tU7             EQU TS00+0778h  ; 29 29, CRC U7
tDMU2           EQU TS00+077Ah
tU2             EQU TS00+077Ah  ; 29 30, CRC U2
tDMLWR          EQU TS00+077Ch
tLower          EQU TS00+077Ch  ; 29 31, CRC Lower
tDMUPR          EQU TS00+077Eh
tUpper          EQU TS00+077Eh  ; 29 32, CRC Upper, Place to put resulting CR
tDDDIAGS        EQU TS00+0780h       ; *G*
                               ; 0782
                               ; 0784
                               ; 0786
                               ; 0788
                               ; 078A
                               ; 078C
                               ; 078E
                               ; 0790
                               ; 0792
                               ; 0794
                               ; 0796
                               ; 0798
                               ; 079A
                               ; 079C
                               ; 079E
                               ; 07A0
                               ; 07A2
                               ; 07A4
                               ; 07A6
                               ; 07A8
                               ; 07AA
                               ; 07AC
                               ; 07AE
                               ; 07B0
                               ; 07B2
                               ; 07B4
                               ; 07B6
                               ; 07B8
                               ; 07BA
                               ; 07BC
                               ; 07BE
LFVP5DA               EQU TS00+07C0h  ; DCE-A +5V
LFVM5DB               EQU TS00+07C1h  ; DCE-B +5V
tMUX_VCC        EQU TS00+07C2h  ; MUX_VCC
tMUX_M52V       EQU TS00+07C3h  ; MUX_M52V
tMUX_VREF       EQU TS00+07C4h  ; MUX_VREF
tMUX_GND1       EQU TS00+07C5h  ; MUX_GND1
tMUX_GND2       EQU TS00+07C6h  ; MUX_GND2
tMUX_GND3       EQU TS00+07C7h  ; MUX_GND3
                               ; 07C8
                               ; 07CA
                               ; 07CC
                               ; 07CE
tDIBexception   EQU TS00+07CEh
tPMONlimit      EQU TS00+07CFh
                               ; 07D0
; moved from 0724h dbb 04-12-00
tHV_A_SET       EQU TS00+07D0h  ; Value for HV A DAC setting
tHV_B_SET       EQU TS00+07D1h  ; Value for HV B DAC setting
                               ; 07D2
tLFHVTGTA       EQU TS00+07D2h  ; Value for HV A DAC setting
tLFHVTGTB       EQU TS00+07D3h  ; Value for HV A DAC setting
                               ; 07D4
                               ; 07D6
                               ; 07D8
                               ; 07DA
                               ; 07DC
                               ; 07DE
                               ; 07E0
                               ; 07E2
                               ; 07E4
                               ; 07E6
                               ; 07E8
                               ; 07EA
                               ; 07EC
                               ; 07EE
                               ; 07F0
                               ; 07F2
                               ; 07F4
                               ; 07F6
                               ; 07F8
                               ; 07FA
                               ; 07FC
                               ; 07FE
                               ; 0800
                               ; 0802
                               ; 0804
                               ; 0806
                               ; 0808
                               ; 080A
                               ; 080C
                               ; 080E
                               ; 0810
                               ; 0812
                               ; 0814
                               ; 0816
                               ; 0818
                               ; 081A
                               ; 081C
                               ; 081E
                               ; 0820
                               ; 0822
                               ; 0824
                               ; 0826
                               ; 0828
                               ; 082A
                               ; 082C
                               ; 082E
                               ; 0830
                               ; 0832
                               ; 0834
                               ; 0836
LIMIT_INDEX        EQU TS00+0838h       ; 0838 for Limit Checking
TENCOUNT           EQU TS00+083Ah       ; Count down timer
tRESETCOUNTER      EQU TS00+083Ch
ENDPACKETTIMESTAMP EQU TS00+083Eh       ; Save timer value - hkpupdate
                               ; 083E
;-----------------------------------------------------------------------------

;*****************************************************************************
;*** Digitizer/TDC ***********************************************************
;*****************************************************************************

;*****************************************************************************
; From G. Murphy Fax Memo 3-14-00
; UPdated to reflect error in swapped address bits a8 & a9, which we fix
; by swapping 1s and 2s, 5s and 6s, 9 and A, D and E in lower nibble.
; dbb 4-17-00
TDC_RESET_MODE  EQU  0          ; this has unknown function and not in ICD!
TDC_STIM_ACTIVE EQU 70h         ; Parameter controls stim
TDC_X_SHIFT     EQU 10h         ; DAC0 adjust XSHIFT thr.
TDC_X_STRETCH   EQU 11h         ; DAC0 adjust XSTRETCH thr.
TDC_B_WALK_X    EQU 12h         ; DAC0 adjust BWALK thr.
TDC_E_WALK_X    EQU 13h         ; DAC0 adjust EWALK thr.

TDC_TTHR_Y      EQU 20h         ; DAC1 adjust TTHR thr.
TDC_Q_LO        EQU 21h         ; DAC1 adjust QLO thr.
TDC_Q_HI        EQU 22h         ; DAC1 adjust QUP thr.
TDC_TTHR_X      EQU 23h         ; DAC1 adjust TTHR thr.

TDC_Y_SHIFT     EQU 30h         ; DAC2 adjust XSHIFT thr.
TDC_Y_STRETCH   EQU 31h         ; DAC2 adjust XSTRETCH thr.
TDC_B_WALK_Y    EQU 32h         ; DAC2 adjust BWALK thr.
TDC_E_WALK_Y    EQU 33h         ; DAC2 adjust EWALK thr.

MDC_X_SHIFT     EQU 40h         ; MUXA sense XSHIFT thr.
MDC_X_STRETCH   EQU 41h         ; MUXA sense XSTRETCH thr.
MDC_B_WALK_X    EQU 42h         ; MUXA sense BWALK thr.
MDC_E_WALK_X    EQU 43h         ; MUXA sense EWALK thr.

MDC_TTHR_Y      EQU 44h         ; MUXA sense TTHR thr.
MDC_Q_LO        EQU 45h         ; MUXA sense QLO thr.
MDC_Q_HI        EQU 46h         ; MUXA sense QUP thr.
MDC_TTHR_X      EQU 47h         ; MUXA sense TTHR thr.

MDC_Y_SHIFT     EQU 60h         ; MUXC sense XSHIFT thr.
MDC_Y_STRETCH   EQU 61h         ; MUXC sense XSTRETCH thr.
MDC_B_WALK_Y    EQU 62h         ; MUXC sense BWALK thr.
MDC_E_WALK_Y    EQU 63h         ; MUXC sense EWALK thr.

MDC_P15V        EQU 50h         ; MUXB sensor
MDC_M15V        EQU 51h         ; MUXB sensor
MDC_VCC         EQU 52h         ; MUXB sensor
MDC_M52V        EQU 53h         ; MUXB sensor

MDC_VREF        EQU 54h         ; MUXB sensor
MDC_GND1        EQU 55h         ; MUXB sensor
MDC_GND2        EQU 56h         ; MUXB sensor
MDC_GND3        EQU 57h         ; MUXB sensor

MDC_GND4        EQU 64h         ; MUXC sensor
MDC_GND5        EQU 65h         ; MUXC sensor
MDC_GND6        EQU 66h         ; MUXC sensor
MDC_GND7        EQU 67h         ; MUXC sensor

;*****************************************************************************
; This is the GALEX digitizer layout, with hkp talkback ids in comments
SP_OFFSET_X     EQU 00h               ; GDGEOFFX
SP_GAIN_X       EQU 01h         ; GDGESCLX
ST_OFFSET_X     EQU 02h         ; GDGBOFFX
ST_GAIN_X       EQU 03h         ; GDGBSCLY
WALK_SP_X       EQU 10h
WALK_ST_X       EQU 11h
DIG_THR_X       EQU 12h
DIG_QLO         EQU 13h
SP_OFFSET_Y     EQU 20h
SP_GAIN_Y       EQU 21h
ST_OFFSET_Y     EQU 22h
ST_GAIN_Y       EQU 23h
WALK_SP_Y       EQU 30h
WALK_ST_Y       EQU 31h
DIG_THR_Y       EQU 32h
DIG_QHI         EQU 33h
MON_SP_OFFSET_X EQU 40h         ;  dig_eoffx
MON_SP_GAIN_X   EQU 41h         ;  dig_escalex
MON_ST_OFFSET_X EQU 42h         ;  dig_boffx
MON_ST_GAIN_X   EQU 43h         ;  dig_bscalex
MON_WALK_SP_X   EQU 44h         ;  dig_ewkx
MON_WALK_ST_X   EQU 45h         ;  dig_bwkx
MON_THR_X       EQU 46h         ;  dig_ttx
MON_QLO         EQU 47h         ;  dig_lqt
MON_P15V        EQU 50h         ;  volt_p15t
MON_M15V        EQU 51h         ;  volt_m15t
MON_VCC         EQU 52h         ;
MON_M52V        EQU 53h         ;
; volt_p6t
; volt_m7t
MON_VREF        EQU 54h         ;
GR1UND          EQU 55h
GR2UND          EQU 56h
GR3UND          EQU 57h
MON_SP_OFFSET_Y EQU 60h         ;  dig_eoffy
MON_SP_GAIN_Y   EQU 61h         ;  dig_escaley
MON_ST_OFFSET_Y EQU 62h         ;  dig_boffy
MON_ST_GAIN_Y   EQU 63h         ;  dig_bscaley
MON_WALK_SP_Y   EQU 64h         ;  dig_ewky
MON_WALK_ST_Y   EQU 65h         ;  dig_bwky
MON_THR_Y       EQU 66h         ;  dig_tty
MON_QHI         EQU 67h         ;  dig_uqt
DIG_STIM_CTL    EQU 70h         ;

;*****************************************************************************
; From FUSE CDC COMMAND DEFINITION by Tony Magoncelli
; LWR_T_THR    EQU   0001$0000B ; adjust TTHR thr.
; LWR_Q_THR    EQU   0001$0001B ; adjust QLO thr.
; UPR_Q_THR    EQU   0001$0010B ; adjust QUP thr.
; BSL_THR      EQU   0001$0011B ; adjust BLTHR thr.
; X_SHIFT_DAC  EQU   0001$0100B ; adjust XSHIFT thr.
; X_SCALE_DAC  EQU   0001$0101B ; adjust XSTRETCH thr.
; BEG_WALK     EQU   0001$0110B ; adjust BWALK thr.
; END_WALK     EQU   0001$0111B ; adjust EWALK thr.
;
; STIM_CTRL    EQU   0010$0000B ; STIM off,swp,na,fix depending on parameter
;
; MUX_P15V     EQU   0100$0000B ; select amon +15V
; MUX_M15V     EQU   0100$0001B ; select amon -15V
; MUX_VCC      EQU   0100$0010B ; select amon VCC
; MUX_M52V     EQU   0100$0011B ; select amon -5.2V
; MUX_VREF     EQU   0100$0100B ; select amon VREF
; ;                  0100$0101b ; undefined MUX select
; ;                  0100$0110b ; undefined MUX select
; ;                  0100$0111b ; undefined MUX select
; MUX_XSHIFT   EQU   0100$1000B ; select amon XSHIFT
; MUX_XSTRETCH EQU   0100$1001B ; select amon XSTRETCH
; MUX_BWALK    EQU   0100$1010B ; select amon BWALK
; MUX_EWALK    EQU   0100$1011B ; select amon EWALK
; MUX_TTHR     EQU   0100$1100B ; select amon TTHR
; MUX_QLO      EQU   0100$1101B ; select amon QLO
; MUX_QUP      EQU   0100$1110B ; select amon QUP
; MUX_BLTHR    EQU   0100$1111B ; select amon BLTHR
;
;*****************************************************************************

;*****************************************************************************
;*** 8051 Output Pins and Register Mnemonics *********************************
;*****************************************************************************
CDC_A_DAV       EQU P1.2       ; bit-address: data valid, CDC-A
CDC_A_NXT       EQU P1.0       ; bit-address: clock-in, CDC-A
CDC_A_DATA      EQU P1.1       ; bit-address: data out, CDC-A

CDC_B_DAV       EQU P1.3       ; bit-address: data valid, CDC-B
CDC_B_NXT       EQU P1.0       ; bit-address: clock-in, CDC-B
CDC_B_DATA      EQU P1.1       ; bit-address: data out, CDC-B

C1_LOCK         EQU P1.4       ; Controls 1 LOCK
fFORMAT         EQU P1.5       ; Does something (?) to the Round Robin ACTEL

$IF MASKS
B0_SELECT       EQU P1.6       ; Bank select for RAM at 8000h
B1_SELECT       EQU P1.7       ; Bank select for RAM at 8000h
$ENDIF
CMD_RESET       EQU P1.7       ; Active low, resets Counter Actel

;   SAMPLING   EQU   P3.4       ; Debug signal for o'scope dbb 1-5-99
HARDRESET       EQU P3.5       ; RESET control line
GPHDIS          EQU P3.3       ; PHDIS control line (GALEX)
CPHDIS          EQU P1.5       ; PHDIS control line (COS)
$IF MASKS
MASKDIS         EQU P3.2       ; MASKDIS control line
$ENDIF

;******************************************
;  The PCA is CH:CL at F9h and E9h        *
;******************************************
CL              EQU 0E9h       ; PCA timer low byte
CH              EQU 0F9h       ; PCA timer high byte

CMOD            EQU 0D9h             ; Let PCA clock source be Timer 0 overflow
CCAPM4          EQU 0DEh       ; CCAPM4 setup as WatchDog Timer
CR              EQU 0DEh       ; Bit in CCON
CCAP4L          EQU 0EEh       ; watchdog comparitor to PCA Counter
CCAP4H          EQU 0FEh       ; watchdog comparitor to PCA Counter

;*** Timer 2   ***************************************************************
TR2             EQU 0CAh       ; T2CON.2
RCAP2L          EQU 0CAh       ; T2 autoreload low byte
RCAP2H          EQU 0CBh       ; T2 autoreload high byte
;dbb 2-5-99 TL2          EQU   0CCh       ;
;dbb 2-5-99 TH2          EQU   0CDh       ;
TF2             EQU 0CFh       ; Timer 2 overflow flag, reset in software
;RELOAD       EQU   0FACBh     ; 0 - number of 75us clock ticks in 1ms
;RELOAD          EQU 0FD66h     ; 0 - number of 75us clock ticks in 500us
;  = 312500/750 = 416.7 ==> FE5F.  Used in GALEX for timing constraints.
RELOAD          EQU 0FC00h     ;  610us -
;RELOAD          EQU 0FD00h     ;  610us -
;RELOAD          EQU 0FE00h     ;  416us - perfect!
;RELOAD          EQU 0FD8Fh     ; 432us - number of 75us clock ticks in 312
;RELOAD          EQU 0FCBEh     ; 566us - number of 75us clock ticks in 312
;RELOAD          EQU 0FE5Fh     ; 302us , 192
;RELOAD          EQU 0FF5Fh     ; 156us

;*** RAM CODE SPACE  *********************************************************
RAMDEST         EQU  8800h     ; dest
RAMSRC          EQU  0800h     ; src
RAMEND          EQU  0C000h    ; end of lower execution area

;*** MUX *********************************************************************
;dbb 2-5-99 ADC_READ     EQU   4100h      ;Base for MUX
MUX             EQU 4000h      ;Base for MUX

U15p4           EQU MUX+08h    ;U15 pin  4
U15p5           EQU MUX+09h    ;U15 pin  5
U15p6           EQU MUX+0Ah    ;U15 pin  6
U15p7           EQU MUX+0Bh    ;U15 pin  7
U15p12          EQU MUX+0Ch    ;U15 pin 12
U15p11          EQU MUX+0Dh    ;U15 pin 11
U15p10          EQU MUX+0Eh    ;U15 pin 10
U15p9           EQU MUX+0Fh    ;U15 pin  9

U16p4           EQU MUX+10h    ;U16 pin  4
U16p5           EQU MUX+11h    ;U16 pin  5
U16p6           EQU MUX+12h    ;U16 pin  6
U16p7           EQU MUX+13h    ;U16 pin  7
U16p12          EQU MUX+14h    ;U16 pin 12
U16p11          EQU MUX+15h    ;U16 pin 11
U16p10          EQU MUX+16h    ;U16 pin 10
U16p9           EQU MUX+17h    ;U16 pin  9

U17p4           EQU MUX+20h    ;U17 pin  4
U17p5           EQU MUX+21h    ;U17 pin  5
U17p6           EQU MUX+22h    ;U17 pin  6
U17p7           EQU MUX+23h    ;U17 pin  7
U17p12          EQU MUX+24h    ;U17 pin 12
U17p11          EQU MUX+25h    ;U17 pin 11
U17p10          EQU MUX+26h    ;U17 pin 10
U17p9           EQU MUX+27h    ;U17 pin  9

U18p4           EQU MUX+40h    ;U18 pin  4
U18p5           EQU MUX+41h    ;U18 pin  5
U18p6           EQU MUX+42h    ;U18 pin  6
U18p7           EQU MUX+43h    ;U18 pin  7
U18p12          EQU MUX+44h    ;U18 pin 12
U18p11          EQU MUX+45h    ;U18 pin 11
U18p10          EQU MUX+8046h  ;U18 pin 10 -- note special mark that indicates
U18p9           EQU MUX+8047h  ;U18 pin  9 -- an input from TDC mux.
TDC_A           EQU MUX+47h    ;U18 pin  9
TDC_B           EQU MUX+87h    ;U29 pin  9 *              *

; The schematic was drawn wrong, so bits A0 and A2 are swapped...
;  this means that the address-order is fixed accordingly
U29p4           EQU MUX+80h    ;U29 pin  4
U29p5           EQU MUX+81h    ;U29 pin  5
U19p6           EQU MUX+8082h  ;U29 pin  6 -- note special mark that indicates
U19p7           EQU MUX+8083h  ;U29 pin  7 -- an input from TDC mux.
U29p12          EQU MUX+84h    ;U29 pin 12
U29p11          EQU MUX+85h    ;U29 pin 11
U29p10          EQU MUX+86h    ;U29 pin 10
U29p9           EQU MUX+87h    ;U29 pin 9

;**************************************************
;*                Macros                          *
;**************************************************
SPARE_CODE   MACRO somebytes
$SAVE
$NOLIST
               REPT somebytes
                 NOP          ;  leave room to upload new command code
               ENDM
$RESTORE
             ENDM

FROGS_CODE   MACRO somebytes
$SAVE
$NOLIST
               REPT somebytes
                 MOV R7,A     ;  assembled to 0xFF, patchable in PROM
               ENDM
$RESTORE
             ENDM

TRAP_CODE  MACRO somebytes
$SAVE
$NOLIST
               REPT somebytes
    NOP                       ; make this an even four bytes
    LJMP   TRAPWILD           ; this will never happen, right?
               ENDM
$RESTORE
             ENDM

;*****************************************************************************
STOREX  MACRO  dest
    MOV    DPTR,#dest         ; load pointer to destination
    MOVX   @DPTR,A            ; and save it
    ENDM                      ; STOREX

;*****************************************************************************
STORNEXT  MACRO
    INC    DPTR
    MOVX   @DPTR,A            ; and save it
    ENDM                      ; STORNEXT

;*****************************************************************************
ASSIGNB MACRO dest, value
    MOV    A,#LOW(value)      ; Store the lower byte of the value
    STOREX dest		      ;  at the address pointed-to by dest
    ENDM                      ; ASSIGNB

;*****************************************************************************
ASSIGNX MACRO dest, value
    ASSIGNB dest, value       ; load the lower byte of value to dest, LSB
    MOV    A,#HIGH(value)     ;  then get the upper byte of value
    STORNEXT		      ; and load the upper byte to dest, MSB
    ENDM                      ; ASSIGNX

;*****************************************************************************
FETCHX  MACRO  src
    MOV    DPTR,#src          ; load pointer to source
    MOVX   A,@DPTR            ; and fetch it
    ENDM                      ; FETCHX

;*****************************************************************************
FETCHNEXT  MACRO  src
    INC    DPTR		      ; point to the next item in external memory
    MOVX   A,@DPTR            ; and fetch it
    ENDM                      ; FETCHNEXT

;*****************************************************************************
PUSHDPTR MACRO
    PUSH   DPL		      ; save the lower byte of the DPTR
    PUSH   DPH		      ; save the upper byte of the DPTR
    ENDM                      ; PUSHDPTR

;*****************************************************************************
POPDPTR MACRO
    POP    DPH                ; restore the upper byte of DPTR
    POP    DPL		      ; restore the lower byte of DPTR
    ENDM                      ; POPDPTR

;*****************************************************************************
REPORT_DIAG MACRO err16
    PUSHDPTR		      ; save DPTR since we are about to overwrite it
    MOV    DPTR,#err16        ; The diagnostic code is passed in DPTR
    CALL   REPORT_DIAGNOSTIC  ; Record this diagnostic event
    POPDPTR		      ; restore DPTR to whatever it was before
    ENDM                      ; REPORT_DIAG

;*****************************************************************************
TOGLEDS MACRO bitpattern
    MOV    A,#bitpattern      ; select the bits to be toggled
    CALL   TOG_LEDS	      ; toggle the LEDs bits selected
    ENDM                      ; TOGLEDS

;*****************************************************************************
SETLEDS MACRO bitpattern
    MOV    A,#bitpattern      ; select the bits to be set
    CALL   SET_LEDS	      ; set the LEDs bits selected
    ENDM                      ; SETLEDS

;*****************************************************************************
CLRLEDS MACRO bitpattern
    MOV    A,#bitpattern      ; select the bits to be cleared
    CALL   CLR_LEDS	      ; clear the LEDs bits selected
    ENDM                      ; CLRLEDS

;*****************************************************************************
FILL_XDATA MACRO value,startloc,lastloc
    MOV    R2,#LOW(lastloc)   ; save the low and high bytes of DPTR in
    MOV    R3,#HIGH(lastloc)  ; registers for easy detection of last address
    MOV    DPTR,#startloc     ; DPTR holds address of memory to be filled
    MOV    A,#value           ; let A hold the test value
    CALL   FILL_RAM_VALUE     ; fill external memory at DPTR with some value
    ENDM                      ; FILL_XDATA

;*****************************************************************************
PRESETCRC MACRO
    MOV    CRCH,#0FFH         ; preset CRC to FFFF
    MOV    CRCL,#0FFH         ; preset CRC to FFFF
    ENDM                      ; PRESETCRC

;*****************************************************************************
; This is the handshake for the IDS, indicating that the DPU is no longer
;   using the dual-port memory shared with the 1533/IDS
;*****************************************************************************
;  Let's see if I got this right:  There are two sets of counters, each
;    counter is 24-bits or 3-bytes -- but they are located at 4-byte
;    intervals.  Each set of counters has just two: SiCa & LiFl.
;*****************************************************************************
MV2REG MACRO regid
    MOVX   A,@DPTR            ; fetch the byte from counter
    MOV    regid,A            ; save the byte in a register
    INC    DPTR               ; point to the next-byte
    ENDM                      ; MV2REG

;*****************************************************************************
REG2DP MACRO regid
    MOV    A,regid            ; fetch the byte from a register
    MOVX   @DPTR,A            ; load value to memory
    INC    DPTR               ; point to the next-byte
    ENDM                      ; REG2DP

;*****************************************************************************
; Note: R3 should be 0, since counters are 24-bits -- right?
MOV_COUNTER MACRO ctr_addr, ts_addr
    MOV    DPTR,#ctr_addr     ; load the address of the counter
    MV2REG R0                 ; save in a register
    MV2REG R1                 ; save in a register
    MV2REG R2                 ; save in a register
    MOV    DPTR,#ts_addr      ; load the address of the destination
    REG2DP R0                 ; load from register to memory
    REG2DP R1                 ; load from register to memory
    REG2DP R2                 ; load from register to memory
    REG2DP R3                 ; always 0
    ENDM                      ; MOV_COUNTER

;*****************************************************************************
;  The PCA is CH:CL at F9h and E9h
MOV_TIMER MACRO dest_addr
    MOV    A,CL               ; fetch CL, low byte of PCA timer
    STOREX dest_addr          ; Timer destination, store the LSB
    MOV    A,CH               ; fetch CH, high byte of PCA timer
    STORNEXT		      ; write to external memory, MSB
    ENDM                      ; MOV_TIMER

;*****************************************************************************
                              ; changed form 24 to 27 because v17036
                              ; would always get diag 7 during upload
StakMax      EQU     2Ah      ; stack size provided by map listing
                              ; Increased by 3 to 2A for v17046

;*****************************************************************************
$IF (PATCHCST)
PUBLIC       ACT1_BIT
PUBLIC       ACT2_BIT
PUBLIC       ACT_EN_BIT
PUBLIC       ASSERTED         ; for REDUCE/RESTORE command detection
PUBLIC       AUX_PWR_ENA_BIT
PUBLIC       CLOCK_TICK       ; toggles on every interrupt
PUBLIC       CLOCK_TOCK       ; toggles on every second
PUBLIC       CMD_ERR
PUBLIC       CODESpace        ; true when running out of upper code space
PUBLIC       CTRS_FLAG
PUBLIC       ESS_FLAG
PUBLIC       GF0
PUBLIC       GPFLAG           ; When set, indicates a second just ended
PUBLIC       HKP_FULL         ; force hkp send of size 512 dwords
PUBLIC       HVQ_ON_BIT            ; reset state flag
PUBLIC       HVSDA            ; When set, indicates HV shutdown already
PUBLIC       HVSDB            ; When set, indicates HV shutdown already
PUBLIC       HV_ARM_BIT
PUBLIC       HV_ON_BIT
PUBLIC       LASTSAMPLE
PUBLIC       LATCH_FLAG
PUBLIC       MOTOR_ARM_BIT
PUBLIC       MOTOR_CNTRL_A_BIT
PUBLIC       MOTOR_CNTRL_B_BIT
PUBLIC       MOTOR_ENA_BIT    ; Allow command cycle overwrite per motor_ena
PUBLIC       MUX_FLAG
PUBLIC       NOP_FLAG
PUBLIC       OPERATES         ; set indicates OPERATE mode, else BOOT
PUBLIC       PHS_FLAG
PUBLIC       PROJECT          ; set indicates COS, reset indicates GALEX
PUBLIC       RAMPACMD         ; push ramping along
PUBLIC       RAMPBCMD         ; push ramping along
PUBLIC       RXD_FLAG
PUBLIC       SAA_ASSERT
PUBLIC       SAA_FLAG
PUBLIC       SA_OVERRIDE
PUBLIC       SA_SECOND
PUBLIC       SA_STATE
PUBLIC       SB_OVERRIDE
PUBLIC       SB_SECOND
PUBLIC       SB_STATE
PUBLIC       SKIPDOG
PUBLIC       SKIPSAFE
PUBLIC       SPECIALF              ; unused! dbb 12-5-99
PUBLIC       S_OVER           ; Tell SAA machine to timeout from SAA
PUBLIC       S_TRIGR          ; Tell SAA machine to trigger artificial SAA
PUBLIC       WATCHDOG_STATE
PUBLIC       SENSOR_INDEX
PUBLIC       AUXIINFO
PUBLIC       BEG_WALK
PUBLIC       CDCTABLE
PUBLIC       CMUXTABLE
PUBLIC       COUNTERTABLE
PUBLIC       END_WALK
PUBLIC       GMUXTABLE
PUBLIC       HSTERR_TABLE
PUBLIC       HVIAINFO
PUBLIC       HVIBINFO
PUBLIC       LWR_Q_THR
PUBLIC       LWR_T_THR
PUBLIC       MUX_BWALY        ;
PUBLIC       MUX_B_WALK_X     ; TDC Begin Walk AX   ; sensor
PUBLIC       MUX_EWALY        ; sensor
PUBLIC       MUX_E_WALK_X     ; TDC End Walk AX     ; sensor
PUBLIC       MUX_M15V
PUBLIC       MUX_M52V
PUBLIC       MUX_P15V
PUBLIC       MUX_QLO          ; sensor
PUBLIC       MUX_QUP          ; sensor
PUBLIC       MUX_TTHR_X       ; sensor
PUBLIC       MUX_TTHR_Y       ; sensor
PUBLIC       MUX_VCC
PUBLIC       MUX_VREF
PUBLIC       MUX_XSHIFE
PUBLIC       MUX_XSHIFT       ; TDC Image Shift AX  ; sensor
PUBLIC       MUX_XSTRETCE
PUBLIC       MUX_XSTRETCH     ; TDC Image Stretch AX ; sensor
PUBLIC       MUX_YSHIFE
PUBLIC       MUX_YSHIFT       ; sensor
PUBLIC       MUX_YSTRETCE
PUBLIC       MUX_YSTRETCH     ; sensor
PUBLIC       PHTABLE
PUBLIC       REGION0
PUBLIC       REGION1
PUBLIC       REGION5
PUBLIC       STIM_CONTRL
PUBLIC       UPDATETABLE
PUBLIC       UPR_Q_THR
PUBLIC       WYE_T_THR
PUBLIC       X_SCALE_DAC
PUBLIC       X_SCALE_DAE
PUBLIC       X_SHIFT_DAC
PUBLIC       X_SHIFT_DAE
PUBLIC       YBEGWALK
PUBLIC       YENDWALK
PUBLIC       Y_SCALE_DAC
PUBLIC       Y_SCALE_DAE
PUBLIC       Y_SHIFT_DAC
PUBLIC       Y_SHIFT_DAE
PUBLIC       CMDBUFF
PUBLIC       HKPBUFF
PUBLIC       HKPTMR           ; tick timer for autonomous hkp
PUBLIC       HVI_DELAY
PUBLIC       HVRAMP           ; ramp counter HV ramp
PUBLIC       LAST_CH
PUBLIC       SAA_K_A
PUBLIC       SAA_K_B
PUBLIC       SDBUFFR
PUBLIC       CONTEXT
PUBLIC       CRCH
PUBLIC       CRCL
PUBLIC       CRCSAVEH
PUBLIC       CRCSAVEL
PUBLIC       DXH
PUBLIC       DXL
PUBLIC       GPTMR            ; 1-second timer
PUBLIC       LEDimage         ; hardware readback may not be available
PUBLIC       MEMPTR
PUBLIC       MOTORTMR         ; Motor timeout timer, 1 count = 1 Second
PUBLIC       RESETCTR         ;
PUBLIC       stackAt          ; high-water mark
PUBLIC       TEMP
PUBLIC       TEMP1
PUBLIC       STACK
PUBLIC       AL_STATE
PUBLIC       AR_STATE
PUBLIC       DIAG_PTR         ;
PUBLIC       HVArampcnt       ; ramp counter  HV ramp on side A
PUBLIC       HVAsetting       ; setting HV for HV ramp on side A
PUBLIC       HVBrampcnt       ; ramp counter  HV ramp on side B
PUBLIC       HVBsetting       ; setting HV for HV ramp on side B
PUBLIC       Image2           ;
PUBLIC       Image3           ;
PUBLIC       ISAMPLE
PUBLIC       LastErrInfo
PUBLIC       SAA_A_TICKS      ;
PUBLIC       SAA_B_TICKS      ;
PUBLIC       SAA_TABLE_A      ;
PUBLIC       SAA_TABLE_B
PUBLIC       SAA_TIMEOFF      ;
PUBLIC       SA_CNT_LMT       ; SAA Count Limit for Segment A
PUBLIC       SA_INT_TIME      ; SAA Integration Time for Count Limit, Seg A
PUBLIC       SA_REDUCED       ;
PUBLIC       SA_SAVED         ;
PUBLIC       SB_CNT_LMT       ; SAA Count Limit for Segment B
PUBLIC       SB_INT_TIME      ; SAA Integration Time for Count Limit, Seg B
PUBLIC       SB_REDUCED       ;
PUBLIC       SB_SAVED         ;
PUBLIC       SIDXI
$ELSE
EXTRN BIT   (ACT1_BIT)
EXTRN BIT   (ACT2_BIT)
EXTRN BIT   (ACT_EN_BIT)
EXTRN BIT   (ASSERTED)        ; for REDUCE/RESTORE command detection
EXTRN BIT   (AUX_PWR_ENA_BIT)
EXTRN BIT   (CLOCK_TICK)      ; toggles on every interrupt
EXTRN BIT   (CLOCK_TOCK)      ; toggles on every second
EXTRN BIT   (CMD_ERR)
EXTRN BIT   (CODESpace)       ; true when running out of upper code space
EXTRN BIT   (CTRS_FLAG)
EXTRN BIT   (ESS_FLAG)
EXTRN BIT   (GF0)
EXTRN BIT   (GPFLAG)          ; When set, indicates a second just ended
EXTRN BIT   (HKP_FULL)        ; force hkp send of size 512 dwords
EXTRN BIT   (HVQ_ON_BIT)           ; reset state flag
EXTRN BIT   (HVSDA)           ; When set, indicates HV shutdown already
EXTRN BIT   (HVSDB)           ; When set, indicates HV shutdown already
EXTRN BIT   (HV_ARM_BIT)
EXTRN BIT   (HV_ON_BIT)
EXTRN BIT   (LASTSAMPLE)
EXTRN BIT   (LATCH_FLAG)
EXTRN BIT   (MOTOR_ARM_BIT)
EXTRN BIT   (MOTOR_CNTRL_A_BIT)
EXTRN BIT   (MOTOR_CNTRL_B_BIT)
EXTRN BIT   (MOTOR_ENA_BIT)   ; Allow command cycle overwrite per motor_ena
EXTRN BIT   (MUX_FLAG)
EXTRN BIT   (NOP_FLAG)
EXTRN BIT   (OPERATES)        ; set indicates OPERATE mode, else BOOT
EXTRN BIT   (PHS_FLAG)
EXTRN BIT   (PROJECT)         ; set indicates COS, reset indicates GALEX
EXTRN BIT   (RAMPACMD)        ; push ramping along
EXTRN BIT   (RAMPBCMD)        ; push ramping along
EXTRN BIT   (RXD_FLAG)
EXTRN BIT   (SAA_ASSERT)
EXTRN BIT   (SAA_FLAG)
EXTRN BIT   (SA_OVERRIDE)
EXTRN BIT   (SA_SECOND)
EXTRN BIT   (SA_STATE)
EXTRN BIT   (SB_OVERRIDE)
EXTRN BIT   (SB_SECOND)
EXTRN BIT   (SB_STATE)
EXTRN BIT   (SKIPDOG)
EXTRN BIT   (SKIPSAFE)
EXTRN BIT   (SPECIALF)        ; Used to select source memory for copy
EXTRN BIT   (S_OVER)          ; Tell SAA machine to timeout from SAA
EXTRN BIT   (S_TRIGR)         ; Tell SAA machine to trigger artificial SAA
EXTRN BIT   (WATCHDOG_STATE)
EXTRN CODE  (SENSOR_INDEX)
EXTRN CODE  (AUXIINFO)
EXTRN CODE  (BEG_WALK)
EXTRN CODE  (CDCTABLE)
EXTRN CODE  (CMUXTABLE)
EXTRN CODE  (COUNTERTABLE)
EXTRN CODE  (END_WALK)
EXTRN CODE  (GMUXTABLE)
EXTRN CODE  (HSTERR_TABLE)
EXTRN CODE  (HVIAINFO)
EXTRN CODE  (HVIBINFO)
EXTRN CODE  (LWR_Q_THR)
EXTRN CODE  (LWR_T_THR)
EXTRN CODE  (MUX_BWALY)       ;
EXTRN CODE  (MUX_B_WALK_X)    ; TDC Begin Walk AX   ; sensor
EXTRN CODE  (MUX_EWALY)       ; sensor
EXTRN CODE  (MUX_E_WALK_X)    ; TDC End Walk AX     ; sensor
EXTRN CODE  (MUX_M15V)
EXTRN CODE  (MUX_M52V)
EXTRN CODE  (MUX_P15V)
EXTRN CODE  (MUX_QLO)         ; sensor
EXTRN CODE  (MUX_QUP)         ; sensor
EXTRN CODE  (MUX_TTHR_X)      ; sensor
EXTRN CODE  (MUX_TTHR_Y)      ; sensor
EXTRN CODE  (MUX_VCC)
EXTRN CODE  (MUX_VREF)
EXTRN CODE  (MUX_XSHIFE)
EXTRN CODE  (MUX_XSHIFT)      ; TDC Image Shift AX  ; sensor
EXTRN CODE  (MUX_XSTRETCE)
EXTRN CODE  (MUX_XSTRETCH)    ; TDC Image Stretch AX ; sensor
EXTRN CODE  (MUX_YSHIFE)
EXTRN CODE  (MUX_YSHIFT)      ; sensor
EXTRN CODE  (MUX_YSTRETCE)
EXTRN CODE  (MUX_YSTRETCH)    ; sensor
EXTRN CODE  (PHTABLE)
EXTRN CODE  (REGION0)
EXTRN CODE  (REGION1)
EXTRN CODE  (REGION5)
EXTRN CODE  (STIM_CONTRL)
EXTRN CODE  (UPDATETABLE)
EXTRN CODE  (UPR_Q_THR)
EXTRN CODE  (WYE_T_THR)
EXTRN CODE  (X_SCALE_DAC)
EXTRN CODE  (X_SCALE_DAE)
EXTRN CODE  (X_SHIFT_DAC)
EXTRN CODE  (X_SHIFT_DAE)
EXTRN CODE  (YBEGWALK)
EXTRN CODE  (YENDWALK)
EXTRN CODE  (Y_SCALE_DAC)
EXTRN CODE  (Y_SCALE_DAE)
EXTRN CODE  (Y_SHIFT_DAC)
EXTRN CODE  (Y_SHIFT_DAE)
EXTRN DATA  (CMDBUFF)
EXTRN DATA  (HKPBUFF)
EXTRN DATA  (HKPTMR)          ; tick timer for autonomous hkp
EXTRN DATA  (HVI_DELAY)
EXTRN DATA  (HVRAMP)          ; ramp counter HV ramp
EXTRN DATA  (LAST_CH)
EXTRN DATA  (SAA_K_A)
EXTRN DATA  (SAA_K_B)
EXTRN DATA  (SDBUFFR)
EXTRN DATA  (CONTEXT)
EXTRN DATA  (CRCH)
EXTRN DATA  (CRCL)
EXTRN DATA  (CRCSAVEH)
EXTRN DATA  (CRCSAVEL)
EXTRN DATA  (DXH)
EXTRN DATA  (DXL)
EXTRN DATA  (GPTMR)           ; 1-second timer
EXTRN DATA  (LEDimage)        ; hardware readback may not be available
EXTRN DATA  (MEMPTR)
EXTRN DATA  (MOTORTMR)        ; Motor timeout timer, 1 count = 1 Second
EXTRN DATA  (RESETCTR)        ;
EXTRN DATA  (stackAt)         ; high-water mark
EXTRN DATA  (TEMP)
EXTRN DATA  (TEMP1)
EXTRN IDATA (STACK)
EXTRN XDATA (AL_STATE)
EXTRN XDATA (AR_STATE)
EXTRN XDATA (DIAG_PTR)        ;
EXTRN XDATA (HVArampcnt)      ; ramp counter  HV ramp on side A
EXTRN XDATA (HVAsetting)      ; setting HV for HV ramp on side A
EXTRN XDATA (HVBrampcnt)      ; ramp counter  HV ramp on side B
EXTRN XDATA (HVBsetting)      ; setting HV for HV ramp on side B
EXTRN XDATA (Image2)          ;
EXTRN XDATA (Image3)          ;
EXTRN XDATA (ISAMPLE)
EXTRN XDATA (LastErrInfo)
EXTRN XDATA (SAA_A_TICKS)     ;
EXTRN XDATA (SAA_B_TICKS)     ;
EXTRN XDATA (SAA_TABLE_A)     ;
EXTRN XDATA (SAA_TABLE_B)
EXTRN XDATA (SAA_TIMEOFF)     ;
EXTRN XDATA (SA_CNT_LMT)      ; SAA Count Limit for Segment A
EXTRN XDATA (SA_INT_TIME)     ; SAA Integration Time for Count Limit, Seg A
EXTRN XDATA (SA_REDUCED)      ;
EXTRN XDATA (SA_SAVED)        ;
EXTRN XDATA (SB_CNT_LMT)      ; SAA Count Limit for Segment B
EXTRN XDATA (SB_INT_TIME)     ; SAA Integration Time for Count Limit, Seg B
EXTRN XDATA (SB_REDUCED)      ;
EXTRN XDATA (SB_SAVED)        ;
EXTRN XDATA (SIDXI)	      ;
$ENDIF

;*****************************************************************************
$IF (MAIN_EXECUTIVE)
PUBLIC CHECKRXDFLAG
PUBLIC CONVERT_A2D
PUBLIC COPYRITE
PUBLIC DMPPACKET              ; send dump buffer
PUBLIC GETMUXINFO
PUBLIC PROGRAMMONITOR         ; index,addr,bank
PUBLIC REENTRY
PUBLIC SAA_A_INIT
PUBLIC SAA_B_INIT
PUBLIC SETPROJECT
PUBLIC UPDATE_MUX             ; Copies ADC to SA space
PUBLIC VERSION
$ELSE
EXTRN CODE  (CHECKRXDFLAG)
EXTRN CODE  (CONVERT_A2D)
EXTRN CODE  (COPYRITE)
EXTRN CODE  (DMPPACKET)       ; send dump packet
EXTRN CODE  (GETMUXINFO)
EXTRN CODE  (PROGRAMMONITOR)  ; index,addr,bank
EXTRN CODE  (REENTRY)
EXTRN CODE  (SAA_A_INIT)
EXTRN CODE  (SAA_B_INIT)
EXTRN CODE  (SETPROJECT)
EXTRN CODE  (UPDATE_MUX)      ; Copies ADC to SA space
EXTRN CODE  (VERSION)
$ENDIF

;*****************************************************************************
$IF INTERNAL
PUBLIC  INIT_REGION
PUBLIC  RM0
PUBLIC  RM1
PUBLIC  RXD1READ
PUBLIC  RXD0READ
PUBLIC  IVTINDIR
PUBLIC  CLR_LEDS
PUBLIC  SET_LEDS
PUBLIC  TOG_LEDS
$ELSE
EXTRN CODE  (INIT_REGION)
EXTRN CODE  (RM0)
EXTRN CODE  (RM1)
EXTRN CODE  (RXD1READ)
EXTRN CODE  (RXD0READ)
EXTRN CODE  (IVTINDIR)
EXTRN CODE  (TOG_LEDS)
EXTRN CODE  (SET_LEDS)
EXTRN CODE  (CLR_LEDS)
$ENDIF

;*****************************************************************************
$IF COMMANDS
PUBLIC BRIDGE_OFF
PUBLIC cACT_ENA              ; ARMS 28V ACTUATOR PWR SWITCH
PUBLIC CALC_CRC
PUBLIC CDC_A_OUT              ; Command to Science Data Processor
PUBLIC CDC_B_OUT              ; Command to Science Data Processor
;PUBLIC cFORMAT
PUBLIC CHECK_COMMAND          ; entry point to command processor
PUBLIC DOOR_I_MAX
PUBLIC DOOR_STOP
PUBLIC HARD_RESET
PUBLIC HKPFULL                ; set flag to force 512 dword hkp packet
PUBLIC HV_A_DAC
PUBLIC HV_B_DAC
PUBLIC INCREMENT_WORD         ; for packet counter updates, etc
PUBLIC MEM_COPY
PUBLIC REPORT_DIAGNOSTIC      ; diagnostic code in R1:R0
PUBLIC SAFE_CONTROLS          ; Force controls to a safe state
PUBLIC SOFT_RESET
PUBLIC TABLE_COPY
PUBLIC WD_DISABLE
PUBLIC WD_ENABLE
PUBLIC ZAPCODECRC
$ELSE
;EXTRN CODE (BRIDGE_OFF)
EXTRN CODE (cACT_ENA)         ; ARMS 28V ACTUATOR PWR SWITCH
;EXTRN CODE (CALC_CRC)
EXTRN CODE (CDC_A_OUT)        ; Command to Science Data Processor
EXTRN CODE (CDC_B_OUT)        ; Command to Science Data Processor
EXTRN CODE (CHECK_COMMAND)    ; entry point to command processor
EXTRN CODE (DOOR_I_MAX)
EXTRN CODE (DOOR_STOP)
EXTRN CODE (HARD_RESET)
EXTRN CODE (HKPFULL)          ; force full-sized hkp packet
EXTRN CODE (HV_A_DAC)
EXTRN CODE (HV_B_DAC)
EXTRN CODE (INCREMENT_WORD)   ; for packet counter updates
EXTRN CODE (MEM_COPY)
EXTRN CODE (REPORT_DIAGNOSTIC) ; Record a diagnostic code
EXTRN CODE (SAFE_CONTROLS)    ; Force controls to a safe state
EXTRN CODE (SOFT_RESET)
EXTRN CODE (TABLE_COPY)
EXTRN CODE (WD_DISABLE)
EXTRN CODE (WD_ENABLE)
EXTRN CODE (ZAPCODECRC)
$ENDIF
;*****************************************************************************
$IF INTERNAL
PUBLIC INIT_TEST_BKGRND
PUBLIC BYTE_MOVE
PUBLIC FILL_RAM_VALUE
PUBLIC BACKGROUND
PUBLIC ZAP_TS30
PUBLIC TRAPWILD
PUBLIC ONE_SECOND
PUBLIC HKP_SECOND
PUBLIC FEED_DOG
PUBLIC INIT_WD
PUBLIC INIT_T0
$ELSE
EXTRN CODE  (BYTE_MOVE)
EXTRN CODE  (FILL_RAM_VALUE)  ; value to fill passed in A
EXTRN CODE  (INIT_TEST_BKGRND)
EXTRN CODE  (BACKGROUND)
EXTRN CODE  (ZAP_TS30)
EXTRN CODE  (HKP_SECOND)      ; sets GPFLAG in one second
EXTRN CODE  (TRAPWILD)        ; trap wild code
EXTRN CODE  (ONE_SECOND)      ; sets TOCK in one second
EXTRN CODE  (FEED_DOG)        ; in HARDWARE.a51
EXTRN CODE  (INIT_WD)         ; in HARDWARE.a51
EXTRN CODE  (INIT_T0)         ; start interrupt-driven timer GPTMR
$ENDIF
$RESTORE
